<?php
/**
 * Web Artist: Color Patterns
 *
 * @package WordPress
 * @subpackage Web Artist
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function web_artist_pro_custom_colors_css() {
  	$options= web_artist_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	.backtotop,
	#respond input[type="submit"]:hover,
	#respond input[type="submit"]:focus,
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	.widget_search form.search-form .search-submit:hover,
	.widget_search form.search-form .search-submit:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	.jetpack_subscription_widget input[type="submit"],
	.jetpack_subscription_widget input[type="submit"]:hover,
	.jetpack_subscription_widget input[type="submit"]:focus,
	#secondary .jetpack_subscription_widget input[type="submit"]:hover,
	#secondary .jetpack_subscription_widget input[type="submit"]:focus,
	.slick-prev,
	.slick-next,
	.slick-prev:hover,
	.slick-next:hover,
	.slick-dots li.slick-active button,
	.featured-search input[type="submit"],
	#topics article:hover .topic-wrapper,
	.btn-fill,
	.seperator,
	.single .posted-on a,
	.woocommerce div.product form.cart .button:hover, 
	.woocommerce div.product form.cart .button:focus,
	.woocommerce #review_form #respond .form-submit input[type="submit"],
	.reply a:hover, 
	.reply a:focus {
	    background-color: ' . esc_attr($color_value) . ';
	}
	.woocommerce #review_form #respond .form-submit input[type="submit"]:hover, 
	.woocommerce #review_form #respond .form-submit input[type="submit"]:focus {
		background-color: transparent;
	}
	.main-navigation ul#primary-menu li.current-menu-item > a,
	.main-navigation ul#primary-menu li:hover > a,
	.main-navigation a:hover,
	.main-navigation ul.nav-menu > li > a:hover,
	#masthead .site-title a:hover, 
	#masthead .site-title a:focus,
	.btn,
	.topic-icon .fa,
	a:hover, 
	a:focus, 
	a:active,
	.service-icon .fa,
	.post-categories a,
	.posted-on a:hover, 
	.posted-on a:focus,
	.archive-blog-wrapper .entry-content a,
	#colophon a:hover, 
	#colophon a:focus,
	#colophon .site-info a,
	#secondary a:hover, 
	#secondary a:focus,
	.single .post-categories a, 
	.single .byline a,
	.post-navigation a:hover, 
	.posts-navigation a:hover, 
	.post-navigation a:focus, 
	.posts-navigation a:focus,
	.woocommerce-loop-product__title:hover,
	.woocommerce p.stars a, 
	.woocommerce div.product .woocommerce-tabs ul.tabs li a:hover, 
	.woocommerce div.product .woocommerce-tabs ul.tabs li.active a,
	.woocommerce #review_form #respond .form-submit input[type="submit"]:hover, 
	.woocommerce #review_form #respond .form-submit input[type="submit"]:focus,
	.comment-metadata a:hover, 
	.comment-metadata a:focus, 
	.comment-metadata a:hover time, 
	.comment-metadata a:focus time {
		color: ' . esc_attr($color_value) . ';
	}
	.btn-fill {
		color: #fff;
	}
	.single .posted-on a:hover time,
	.single .posted-on a:focus time {
		opacity: 0.8;
		color: #fff;
	}
	.main-navigation ul#primary-menu li:hover > svg,
	.main-navigation li.menu-item-has-children:hover > a > svg,
	.main-navigation li.menu-item-has-children > a:hover > svg,
	.main-navigation ul#primary-menu > li.current-menu-item > a > svg,
	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
	.main-navigation li.search-menu a:hover svg,
	.main-navigation li.search-menu a:focus svg,
	.main-navigation li.search-menu a.search-active svg,
	.product-search-wrapper .search-submit svg.icon-search,
	.navigation.posts-navigation a:hover svg, 
	.navigation.post-navigation a:hover svg, 
	.navigation.posts-navigation a:focus svg, 
	.navigation.post-navigation a:focus svg,
	.loader-container svg {
	    fill: ' . esc_attr($color_value) . ';
	}
	.woocommerce div.product form.cart .button,
	.woocommerce #review_form #respond .form-submit input[type="submit"],
	.woocommerce #review_form #respond .form-submit input[type="submit"]:hover, 
	.woocommerce #review_form #respond .form-submit input[type="submit"]:focus {
		border-color: ' . esc_attr($color_value) . ';
	}

	@media screen and (min-width: 1024px) {
		.main-navigation ul.sub-menu li:hover > a,
		.main-navigation ul.sub-menu li:focus > a {
		    background-color: ' . esc_attr($color_value) . ';
		}
		#masthead .main-navigation ul#primary-menu > li.current-menu-item > a,
		#masthead .main-navigation ul.nav-menu > li > a:hover,
		.main-navigation ul#primary-menu li:hover > a {
		    color: ' . esc_attr($color_value) . ';
		}
		.main-navigation li.menu-item-has-children:hover > a > svg, 
		.main-navigation li.menu-item-has-children > a:hover > svg,
		.main-navigation ul#primary-menu > li.current-menu-item > a > svg {
			fill: ' . esc_attr($color_value) . ';
		}
	}';

	$css .= '
	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	    25% {height:30px;transform:translateY(15px);background: ' . esc_attr($color_value) . ';}
	    50% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	    100% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	}';

	/**
	 * Filters Web Artist custom colors CSS.
	 *
	 * @since Web Artist 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'web_artist_pro_custom_colors_css', $css );
}
