<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

if ( ! function_exists( 'web_artist_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Web Artist 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function web_artist_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'web_artist_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'web_artist_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Web Artist 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function web_artist_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'web_artist_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'web_artist_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Web Artist 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function web_artist_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'web_artist_pro_theme_options[pagination_enable]' )->value();
	}
endif;

function web_artist_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[counter_section_enable]' )->value() );
}

/**
 * Front Page Active Callbacks
 */

/**
 * Check if slider section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[slider_content_type]' )->value();
	return web_artist_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[slider_content_type]' )->value();
	return web_artist_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[slider_content_type]' )->value();
	return web_artist_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is product.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_slider_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[product_content_type]' )->value();
	return web_artist_pro_is_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_slider_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[product_content_type]' )->value();
	return web_artist_pro_is_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if topic section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_topic_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[topic_section_enable]' )->value() );
}

/**
 * Check if topic section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_topic_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[topic_content_type]' )->value();
	return web_artist_pro_is_topic_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if topic section seperator.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_topic_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[topic_content_type]' )->value();
	return web_artist_pro_is_topic_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if topic section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_topic_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[topic_content_type]' )->value();
	return web_artist_pro_is_topic_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if topic section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_topic_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[topic_content_type]' )->value();
	return web_artist_pro_is_topic_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[service_content_type]' )->value();
	return web_artist_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[service_content_type]' )->value();
	return web_artist_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[service_content_type]' )->value();
	return web_artist_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[service_content_type]' )->value();
	return web_artist_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if artisan section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_artisan_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[artisan_section_enable]' )->value() );
}

/**
 * Check if artisan section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_artisan_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[artisan_content_type]' )->value();
	return web_artist_pro_is_artisan_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if artisan section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_artisan_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[artisan_content_type]' )->value();
	return web_artist_pro_is_artisan_section_enable( $control ) && ( 'page' == $content_type );
}

function web_artist_pro_is_artisan_section_content_shop_manager_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[artisan_content_type]' )->value();
	return web_artist_pro_is_artisan_section_enable( $control ) && ( 'manager' == $content_type );
}

/**
 * Check if artisan section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_artisan_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[artisan_content_type]' )->value();
	return web_artist_pro_is_artisan_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[cta_content_type]' )->value();
	return web_artist_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[cta_content_type]' )->value();
	return web_artist_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[cta_content_type]' )->value();
	return web_artist_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[about_content_type]' )->value();
	return web_artist_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[about_content_type]' )->value();
	return web_artist_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[about_content_type]' )->value();
	return web_artist_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if popular section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if team section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[team_content_type]' )->value();
	return web_artist_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[team_content_type]' )->value();
	return web_artist_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[team_content_type]' )->value();
	return web_artist_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

function web_artist_pro_is_subscribe_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[subscribe_section_enable]' )->value() );
}


/**
 * Check if testimonial section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[testimonial_content_type]' )->value();
	return web_artist_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[testimonial_content_type]' )->value();
	return web_artist_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[testimonial_content_type]' )->value();
	return web_artist_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[testimonial_content_type]' )->value();
	return web_artist_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if testimonial section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if blog section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[blog_content_type]' )->value();
	return web_artist_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[blog_content_type]' )->value();
	return web_artist_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[blog_content_type]' )->value();
	return web_artist_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[blog_content_type]' )->value();
	return web_artist_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}


/**
 * Check if gallery section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[gallery_content_type]' )->value();
	return web_artist_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[gallery_content_type]' )->value();
	return web_artist_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[gallery_content_type]' )->value();
	return web_artist_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if search section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_search_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[search_section_enable]' )->value() );
}

/**
 * Check if product section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[product_content_type]' )->value();
	return web_artist_pro_is_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[product_content_type]' )->value();
	return web_artist_pro_is_product_section_enable( $control ) && ( 'product-category' == $content_type );
}


/**
 * Check if course section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[course_content_type]' )->value();
	return web_artist_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[course_content_type]' )->value();
	return web_artist_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[course_content_type]' )->value();
	return web_artist_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if feature section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_feature_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[feature_section_enable]' )->value() );
}

/**
 * Check if feature section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_feature_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[feature_content_type]' )->value();
	return web_artist_pro_is_feature_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if feature section seperator.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_feature_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[feature_content_type]' )->value();
	return web_artist_pro_is_feature_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if feature section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_feature_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[feature_content_type]' )->value();
	return web_artist_pro_is_feature_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if feature section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_feature_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[feature_content_type]' )->value();
	return web_artist_pro_is_feature_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if reason section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_reason_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[reason_section_enable]' )->value() );
}

/**
 * Check if reason section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_reason_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[reason_content_type]' )->value();
	return web_artist_pro_is_reason_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if reason section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_reason_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[reason_content_type]' )->value();
	return web_artist_pro_is_reason_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reason section content type is custom.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_reason_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[reason_content_type]' )->value();
	return web_artist_pro_is_reason_section_enable( $control ) && ( 'custom' == $content_type );
}

function web_artist_pro_is_partner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[partner_section_enable]' )->value() );
}

function web_artist_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[topbar_section_enable]' )->value() );
}

function web_artist_pro_is_playlist_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[playlist_section_enable]' )->value() );
}


/**
 * Check if release section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_release_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[release_section_enable]' )->value() );
}

/**
 * Check if release section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_release_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[release_content_type]' )->value();
	return web_artist_pro_is_release_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if release section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_release_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[release_content_type]' )->value();
	return web_artist_pro_is_release_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if release section content type is category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_release_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[release_content_type]' )->value();
	return web_artist_pro_is_release_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section is enabled.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[event_content_type]' )->value();
	return web_artist_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[event_content_type]' )->value();
	return web_artist_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[event_content_type]' )->value();
	return web_artist_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_event_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[event_content_type]' )->value();
	return web_artist_pro_is_event_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_event_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[event_content_type]' )->value();
	return web_artist_pro_is_event_section_enable( $control ) && ( 'event-category' == $content_type );
}

/**
 * Check if latest release section is enabled.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_release_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[latest_release_section_enable]' )->value() );
}

/**
 * Check if latest release section content type is post.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_release_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_release_content_type]' )->value();
	return web_artist_pro_is_latest_release_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest release section seperator.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_release_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_release_content_type]' )->value();
	return web_artist_pro_is_latest_release_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if latest release section content type is page.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_release_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_release_content_type]' )->value();
	return web_artist_pro_is_latest_release_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest release section content type is category.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_release_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_release_content_type]' )->value();
	return web_artist_pro_is_latest_release_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest release section content type is product.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_release_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_release_content_type]' )->value();
	return web_artist_pro_is_latest_release_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest release section content type is product category.
 *
 * @since web_artist Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_release_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_release_content_type]' )->value();
	return web_artist_pro_is_latest_release_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if video section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is post.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[video_content_type]' )->value();
	return web_artist_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is page.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[video_content_type]' )->value();
	return web_artist_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is custom.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_video_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[video_content_type]' )->value();
	return web_artist_pro_is_video_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if product section is enabled.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_section_enable( $control ) {
	return ( $control->manager->get_setting( 'web_artist_pro_theme_options[latest_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_content_type]' )->value();
	return web_artist_pro_is_latest_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Web Artist 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function web_artist_pro_is_latest_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'web_artist_pro_theme_options[latest_content_type]' )->value();
	return web_artist_pro_is_latest_section_enable( $control ) && ( 'product-category' == $content_type );
}