<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 * @return array An array of default values
 */

function web_artist_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$web_artist_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#fd2d55',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'web-artist-pro' ), '[the-year]', '[site-link]' ) . esc_html__( ' All Rights Reserved | ', 'web-artist-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'web-artist-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',

		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Main Slider,Topic,Product,Services,Artisan,Call to Action,Popular,Testimonial,Blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'web-artist-pro' ),
		'read_more_text' 				=> esc_html__( 'Read Full Article', 'web-artist-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		'topbar_section_enable'			=> true,
		/* Front Page */

		// Slider
		'slider_section_enable'			=> true,
		'slider_autoplay'				=> false,
		'slider_search_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_excerpt'				=> 25,
		'slider_subtitle'				=> esc_html__('Handmade', 'web-artist-pro'),
		'slider_readmore_text'			=> esc_html__('Read More', 'web-artist-pro'),

		// reason
		'reason_section_enable'			=> true,
		'reason_content_type'			=> 'page',
		'reason_title'					=> esc_html__( 'For Best & Better Quality Product, Choose ', 'web-artist-pro' ),
		'reason_atlernate_text'			=> esc_html__( 'Web Artist!', 'web-artist-pro' ),
		'reason_description'			=> esc_html__( 'Many people are very keen on buying local handicrafts when they travel to places outside their own cultural setting and many are equally happy to pay dearly for genuine handicrafts of good quality...', 'web-artist-pro' ),
		'reason_excerpt'				=> 25,

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'For Best & Better Quality Product, Choose ', 'web-artist-pro' ),
		'about_atlernate_text'			=> esc_html__( 'Web Artist!', 'web-artist-pro' ),
		'about_description'				=> esc_html__( 'Many people are very keen on buying local handicrafts when they travel to places outside their own cultural setting and many are equally happy to pay dearly for genuine handicrafts of good quality...', 'web-artist-pro' ),
		'about_btn_title'				=> esc_html__( 'Learn More', 'web-artist-pro' ),
		'about_excerpt'					=> 25,

		// video
		'video_section_enable'			=> true,
		'video_content_type'			=> 'page',
		'video_title'					=> esc_html__( 'For Best & Better Quality Product, Choose ', 'web-artist-pro' ),
		'video_atlernate_text'			=> esc_html__( 'Web Artist!', 'web-artist-pro' ),
		'video_description'				=> esc_html__( 'Many people are very keen on buying local handicrafts when they travel to places outside their own cultural setting and many are equally happy to pay dearly for genuine handicrafts of good quality...', 'web-artist-pro' ),
		'video_btn_title'				=> esc_html__( 'Learn More', 'web-artist-pro' ),
		'video_excerpt'					=> 25,

		'counter_section_enable' 		=> true,
		'counter_count' 				=> 4,

		// topic
		'topic_title'					=> esc_html__('All Topics', 'web-artist-pro'),
		'topic_button'					=> esc_html__('Show All', 'web-artist-pro'),
		'topic_section_enable'			=> true,
		'topic_content_type'			=> 'category',
		'topic_count'					=> 4,
		'topic_column'					=> 'col-4',

		// Product
		'product_section_enable'		=> false,
		'product_content_type'			=> 'product-category',
		'product_count'					=> 4,
		'product_title'					=> esc_html__( 'Featured Products', 'web-artist-pro' ),
		'product_button'				=> esc_html__( 'Show All', 'web-artist-pro' ),

		
		// service
		'service_title'					=> esc_html__( 'Many Reasons to Choose ', 'web-artist-pro' ),
		'service_sub_title'				=> esc_html__( 'Web Artist!', 'web-artist-pro' ),
		'service_button'				=> esc_html__( 'Learn More', 'web-artist-pro' ),
		'service_bg_image'				=> '',
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_excerpt'				=> 25,

		// Event
		'event_section_enable'			=> true,
		'event_content_type'			=> 'category',
		'event_count'					=> 3,
		'event_title'					=> esc_html__( 'Upcoming Events', 'web-artist-pro' ),
		'event_subtitle'				=> esc_html__( 'Amazing shows around 2019', 'web-artist-pro' ),
		'event_readmore'				=> esc_html__( 'Buy Ticket', 'web-artist-pro' ),
		'event_btn_title'				=> esc_html__( 'View All Events', 'web-artist-pro' ),


		// feature
		'feature_title'					=> esc_html__( 'Many Reasons to Choose ', 'web-artist-pro' ),
		'feature_sub_title'				=> esc_html__( 'Web Artist!', 'web-artist-pro' ),
		'feature_section_enable'		=> true,
		'feature_content_type'			=> 'category',
		'feature_count'					=> 3,
		'feature_excerpt'				=> 25,

		// artisan
		'artisan_section_enable'		=> true,
		'artisan_content_type'			=> 'category',
		'artisan_count'					=> 4,
		'artisan_column'				=> 'col-4',
		'artisan_title'					=> esc_html__( 'The Best ', 'web-artist-pro' ),
		'artisan_subtitle'				=> esc_html__( 'Artisan 2020', 'web-artist-pro' ),
		'artisan_btn_title'				=> esc_html__( 'All Artisans', 'web-artist-pro' ),

		// subscribe
		'subscribe_section_enable'		=> true,
		'subscribe_title'				=> esc_html__( 'Get In Touch', 'web-artist-pro' ),
		'subscribe_sub_title'			=> esc_html__( 'Newsletter', 'web-artist-pro' ),
		'subscribe_btn_label'			=> esc_html__( 'Subscribe Now', 'web-artist-pro' ),
		'subscribe_description'			=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'web-artist-pro' ),

		// Call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'For Best & Better Quality Product, Choose ', 'web-artist-pro' ),
		'cta_atlernate_text'			=> esc_html__( 'Web Artist!', 'web-artist-pro' ),
		'cta_description'				=> esc_html__( 'Many people are very keen on buying local handicrafts when they travel to places outside their own cultural setting and many are equally happy to pay dearly for genuine handicrafts of good quality...', 'web-artist-pro' ),
		'cta_btn_title'					=> esc_html__( 'Learn More', 'web-artist-pro' ),

		// popular
		'popular_section_enable'		=> true,
		'popular_content_type'			=> 'category',
		'popular_title'					=> esc_html__( 'Popular Categories', 'web-artist-pro' ),
		'popular_btn_title'				=> esc_html__( 'All Category', 'web-artist-pro' ), 

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_title'				=> esc_html__( 'What Our Clients Say!', 'web-artist-pro' ),
		'testimonial_subtitle'			=> esc_html__( 'Testimonials', 'web-artist-pro' ),
		'testimonial_button'			=> esc_html__( 'All Testimonials', 'web-artist-pro' ),
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,
		'testimonial_excerpt'			=> 30,
		'testimonial_bg_image'			=> '',

		// team
		'team_section_enable'			=> true,
		'team_content_type'				=> 'category',
		'team_count'					=> 4,
		'team_title'					=> esc_html__( 'Our Team Member', 'web-artist-pro' ),
		'team_sub_title'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'web-artist-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 3,
		'blog_excerpt'					=> 30,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Our Recent Articles', 'web-artist-pro' ),
		'blog_btn_title'				=> esc_html__( 'See More', 'web-artist-pro' ),
		'blog_sub_title'				=> esc_html__( 'OUR BLOG', 'web-artist-pro' ),

		// course
		'course_section_enable'			=> true,
		'course_content_type'			=> 'category',
		'course_count'					=> 3,
		'course_column'					=> 'col-3',
		'course_title'					=> esc_html__( 'Most Valuable Courses', 'web-artist-pro' ),

		// Search
		'search_section_enable'			=> true,
		'search_title'					=> esc_html__( 'The Best Products in Every Category', 'web-artist-pro' ),
		'search_subtitle'				=> esc_html__( 'All Original', 'web-artist-pro' ),
		'search_bg_image'				=> '',		

		'partner_section_enable'		=> true,
		'partner_count'					=> 4,

		'playlist_section_enable'		=> true,

		// latest release
		'latest_release_section_enable'	=> true,
		'latest_release_content_type'	=> 'category',
		'latest_release_title'			=> esc_html__( 'Latest Release', 'web-artist-pro' ),
		'latest_release_subtitle'		=> esc_html__( 'Newest albums & singles.', 'web-artist-pro' ), 
		'latest_release_btn_title'		=> esc_html__( 'View All Release', 'web-artist-pro' ), 
		'latest_release_description'	=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'web-artist-pro' ), 

		// release
		'release_section_enable'		=> true,
		'release_content_type'			=> 'category',
		'release_count'					=> 3,
		'release_title'					=> esc_html__( 'NEW RELEASES', 'web-artist-pro' ),
		'release_btn_title'				=> esc_html__( 'Explore More', 'web-artist-pro' ),
		'release_sub_title'				=> esc_html__( 'Although “music that you like” should be given preference, most people have a fairly wide range of tastes, so using a certain type of music just for work isn’t out of the question.', 'web-artist-pro' ),

		// latest
		'latest_section_enable'			=> false,
		'latest_content_type'			=> 'recent',
		'latest_count'					=> 4,
		'latest_title'					=> esc_html__( 'Featured Product', 'web-artist-pro' ),
		'latest_sub_title'				=> esc_html__( 'quality product', 'web-artist-pro' ),
		'latest_button'					=> esc_html__( 'buy now', 'web-artist-pro' ),
		
		// gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 3,
		'gallery_title'					=> esc_html__( 'Photos Collection', 'web-artist-pro' ),
		'gallery_subtitle'				=> esc_html__( 'Phasellus lorem augue, vulputate vel orci id, ultricies aliquet risus.', 'web-artist-pro' ),
	);

	$output = apply_filters( 'web_artist_pro_default_theme_options', $web_artist_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}