<?php
/**
 * about Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add about section
$wp_customize->add_section( 'web_artist_pro_about_section', array(
	'title'             => esc_html__( 'About','web-artist-pro' ),
	'description'       => esc_html__( 'About Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// about content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_about_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// about subtitle setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_atlernate_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_atlernate_text'],
	'transport'			=> 'postMessage',
) );

if($options['home_layout'] != 'seventh-design') {
	
	$wp_customize->add_control( 'web_artist_pro_theme_options[about_atlernate_text]', array(
		'label'           	=> esc_html__( 'Alternate Title Text', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_about_section',
		'active_callback' 	=> 'web_artist_pro_is_about_section_enable',
		'type'				=> 'text',
	) );
}

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[about_atlernate_text]', array(
		'selector'            => '#about h2.section-title span',
		'settings'            => 'web_artist_pro_theme_options[about_atlernate_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_about_atlernate_text_partial',
    ) );
}

// about content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'web-artist-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_page',
) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_about_section',
	'choices'			=> web_artist_pro_page_choices(),
	'active_callback'	=> 'web_artist_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_page',
) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_about_section',
	'choices'			=> web_artist_pro_post_choices(),
	'active_callback'	=> 'web_artist_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_about_section',
	'active_callback' 	=> 'web_artist_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );



// about description setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_about_section',
	'active_callback' 	=> 'web_artist_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// about image setting and control.
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'web_artist_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'web-artist-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'web-artist-pro' ), 512, 520 ),
		'section'     		=> 'web_artist_pro_about_section',
		'active_callback'	=> 'web_artist_pro_is_about_section_content_custom_enable',
) ) );

$wp_customize->add_setting( 'web_artist_pro_theme_options[about_excerpt]', array(
	'sanitize_callback' => 'absint',
	'default'			=> $options['about_excerpt'],
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[about_excerpt]', array(
	'label'           	=> esc_html__( 'Excerpt Length', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_about_section',
	'active_callback' 	=> 'web_artist_pro_is_about_section_enable',
	'type'				=> 'number',
) );

// about btn title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_about_section',
	'active_callback' 	=> 'web_artist_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about div.read-more a.btn-fill',
		'settings'            => 'web_artist_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_about_btn_title_partial',
    ) );
}
