<?php
/**
 * Artisan Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add Artisan section
$wp_customize->add_section( 'web_artist_pro_artisan_section', array(
	'title'             => esc_html__( 'Artisan','web-artist-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
	) );

// Artisan content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[artisan_section_enable]', array(
	'default'			=> 	$options['artisan_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[artisan_section_enable]', array(
	'label'             => esc_html__( 'Artisan Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_artisan_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
	) ) );

if ( class_exists('WooCommerce') ) {
	// artisan title setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[artisan_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['artisan_title'],
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[artisan_title]', array(
		'label'           	=> esc_html__( 'Title Text', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_artisan_section',
		'active_callback' 	=> 'web_artist_pro_is_artisan_section_enable',
		'type'				=> 'text',
		) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[artisan_title]', array(
			'selector'            => '#artisian .wrapper .section-header h2.section-title',
			'settings'            => 'web_artist_pro_theme_options[artisan_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'web_artist_pro_artisan_title_partial',
			) );
	}

	// artisan subtitle setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[artisan_subtitle]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['artisan_subtitle'],
		) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[artisan_subtitle]', array(
		'label'           	=> esc_html__( 'Alternate Title Text', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_artisan_section',
		'active_callback' 	=> 'web_artist_pro_is_artisan_section_enable',
		'type'				=> 'text',
		) );

	// Event social icons number control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[artisan_count]', array(
		'default'          	=> $options['artisan_count'],
		'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
		'validate_callback' => 'web_artist_pro_validate_artisan_count',
		) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[artisan_count]', array(
		'label'             => esc_html__( 'Number of Artisan', 'web-artist-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
		'section'           => 'web_artist_pro_artisan_section',
		'active_callback'   => 'web_artist_pro_is_artisan_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 10,
			'style' => 'width: 100px;'
			),
		) );


	for ( $i = 1; $i <= $options['artisan_count']; $i++ ) :
		

		$wp_customize->add_setting( 'web_artist_pro_theme_options[artisan_content_owner_' . $i . ']', array(
			'sanitize_callback' => 'absint'
			) );

		$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[artisan_content_owner_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Produts Owner %d', 'web-artist-pro' ), $i ),
			'section'           => 'web_artist_pro_artisan_section',
			'choices'			=> web_artist_pro_product_owner_choices(),
			) ) );

			// artisan social links setting and control
			$wp_customize->add_setting( 'web_artist_pro_theme_options[artisan_social_'. $i .']', array(
				'sanitize_callback' => 'web_artist_pro_sanitize_links'
				) );

			$wp_customize->add_control( new Web_Artist_Pro_Multi_Input_Custom_Control( $wp_customize, 'web_artist_pro_theme_options[artisan_social_'. $i .']',
				array(
					'label'       	  => sprintf( esc_html__( 'Social Links %d', 'web-artist-pro' ), $i ),
					'button_text'     => sprintf( esc_html__( 'Add More Social Link', 'web-artist-pro' ), $i ),
					'section'         => 'web_artist_pro_artisan_section',
					'active_callback' => 'web_artist_pro_is_artisan_section_enable',
					'type'			  => 'multi-input'
					) ) );
	endfor;



}
