<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'web_artist_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','web-artist-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_blog_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// blog title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_blog_section',
	'active_callback' 	=> 'web_artist_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[blog_title]', array(
		'selector'            => '#recent .wrapper h2.section-title',
		'settings'            => 'web_artist_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_blog_title_partial',
    ) );
}

if ( $options['home_layout'] == 'fourth-design' ) {
	$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_sub_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['blog_sub_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[blog_sub_title]', array(
		'label'           	=> esc_html__( 'Sub Title', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_blog_section',
		'active_callback' 	=> 'web_artist_pro_is_blog_section_enable',
		'type'				=> 'text',
	) );
}


// blog btn title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[blog_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_blog_section',
	'active_callback' 	=> 'web_artist_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[blog_btn_title]', array(
		'selector'            => '#recent div.section-header-wrapper a.btn',
		'settings'            => 'web_artist_pro_theme_options[blog_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_blog_btn_title_partial',
    ) );
}

$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_excerpt]', array(
		'default'			=> $options['blog_excerpt'],
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[blog_excerpt]', array(
		'label'           	=> esc_html__( 'Blog Excerpt', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_blog_section',
		'active_callback' 	=> 'web_artist_pro_is_blog_section_enable',
		'type'				=> 'number',
	) );

if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design'  ) {
	// blog btn title setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_btn_url]', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[blog_btn_url]', array(
		'label'           	=> esc_html__( 'Button Link', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_blog_section',
		'active_callback' 	=> 'web_artist_pro_is_blog_section_enable',
		'type'				=> 'url',
	) );
}


// Blog content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_column]', array(
	'default'          	=> $options['blog_column'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[blog_column]', array(
	'label'             => esc_html__( 'Column Layout', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_blog_section_enable',
	'choices'			=> array( 
		'col-2' 	=> esc_html__( 'Two Column', 'web-artist-pro' ),
		'col-3' 	=> esc_html__( 'Three Column', 'web-artist-pro' ),
		'col-4' 	=> esc_html__( 'Four Column', 'web-artist-pro' ),
	),
) );

// Blog content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'category' 	=> esc_html__( 'Category', 'web-artist-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'web-artist-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
	'validate_callback' => 'web_artist_pro_validate_blog_count',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_blog_section',
	'active_callback'   => 'web_artist_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_blog_section',
		'choices'			=> web_artist_pro_page_choices(),
		'active_callback'	=> 'web_artist_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_blog_section',
		'choices'			=> web_artist_pro_post_choices(),
		'active_callback'	=> 'web_artist_pro_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'web_artist_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'web_artist_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Category_Control( $wp_customize,'web_artist_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'web_artist_pro_is_blog_section_content_recent_enable'
) ) );
