<?php
/**
 * feature Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add feature section
$wp_customize->add_section( 'web_artist_pro_feature_section', array(
	'title'             => esc_html__( 'Features','web-artist-pro' ),
	'description'       => esc_html__( 'Features Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// feature content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_section_enable]', array(
	'default'			=> 	$options['feature_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[feature_section_enable]', array(
	'label'             => esc_html__( 'feature Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_feature_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// feature title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['feature_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[feature_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_feature_section',
	'active_callback' 	=> 'web_artist_pro_is_feature_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[feature_title]', array(
		'selector'            => '#our-features .section-header .section-title',
		'settings'            => 'web_artist_pro_theme_options[feature_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_feature_title_partial',
    ) );
}

// feature sub_title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['feature_sub_title'],
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[feature_sub_title]', array(
	'label'           	=> esc_html__( 'Alternate Title Text', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_feature_section',
	'active_callback' 	=> 'web_artist_pro_is_feature_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_excerpt]', array(
	'sanitize_callback' => 'absint',
	'default'			=> $options['feature_excerpt'],
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[feature_excerpt]', array(
	'label'           	=> esc_html__( 'Excerpt Length', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_feature_section',
	'active_callback' 	=> 'web_artist_pro_is_feature_section_enable',
	'type'				=> 'number',
) );



// feature content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_content_type]', array(
	'default'          	=> $options['feature_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[feature_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_feature_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_feature_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'category' 	=> esc_html__( 'Category', 'web-artist-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_count]', array(
	'default'          	=> $options['feature_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
	'validate_callback' => 'web_artist_pro_validate_feature_count',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[feature_count]', array(
	'label'             => esc_html__( 'Number of features', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_feature_section',
	'active_callback'   => 'web_artist_pro_is_feature_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['feature_count']; $i++ ) :


	// feature note control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Icon_Picker( $wp_customize, 'web_artist_pro_theme_options[feature_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_feature_section',
		'active_callback'	=> 'web_artist_pro_is_feature_section_enable',
	) ) );

	

	// feature pages drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_content_page_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[feature_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_feature_section',
		'choices'			=> web_artist_pro_page_choices(),
		'active_callback'	=> 'web_artist_pro_is_feature_section_content_page_enable',
	) ) );

	// feature posts drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_content_post_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[feature_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_feature_section',
		'choices'			=> web_artist_pro_post_choices(),
		'active_callback'	=> 'web_artist_pro_is_feature_section_content_post_enable',
	) ) );

	// feature hr setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[feature_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Customize_Horizontal_Line( $wp_customize, 'web_artist_pro_theme_options[feature_hr_'. $i .']',
		array(
			'section'         => 'web_artist_pro_feature_section',
			'active_callback' => 'web_artist_pro_is_feature_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[feature_content_category]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[feature_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_feature_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'web_artist_pro_is_feature_section_content_category_enable'
) ) );
