<?php
/**
 * latest Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add latest section
$wp_customize->add_section( 'web_artist_pro_latest_section', array(
	'title'             => esc_html__( 'Product','web-artist-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// latest content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[latest_section_enable]', array(
	'default'			=> 	$options['latest_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[latest_section_enable]', array(
	'label'             => esc_html__( 'Latest Products Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_latest_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// latest title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[latest_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[latest_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_latest_section',
	'active_callback' 	=> 'web_artist_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[latest_title]', array(
		'selector'            => '#latest-section .section-header h2.section-title',
		'settings'            => 'web_artist_pro_theme_options[latest_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_latest_title_partial',
    ) );
}

// latest title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[latest_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[latest_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_latest_section',
	'active_callback' 	=> 'web_artist_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// latest button setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[latest_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[latest_button]', array(
	'label'           	=> esc_html__( 'Btn Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_latest_section',
	'active_callback' 	=> 'web_artist_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[latest_button]', array(
		'selector'            => '#latest-section a.btn',
		'settings'            => 'web_artist_pro_theme_options[latest_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_latest_button_partial',
    ) );
}

// latest content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[latest_content_type]', array(
	'default'          	=> $options['latest_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[latest_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_latest_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_latest_section_enable',
	'choices'			=> web_artist_pro_product_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[latest_count]', array(
	'default'          	=> $options['latest_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
	'validate_callback' => 'web_artist_pro_validate_latest_count',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[latest_count]', array(
	'label'             => esc_html__( 'Number of latest', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_latest_section',
	'active_callback'   => 'web_artist_pro_is_latest_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['latest_count']; $i++ ) :

	// latest posts drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[latest_content_product_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[latest_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select latest %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_latest_section',
		'choices'			=> web_artist_pro_product_choices(),
		'active_callback'	=> 'web_artist_pro_is_latest_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[latest_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[latest_content_product_category]', array(
	'label'             => esc_html__( 'Select latest Category', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_latest_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'web_artist_pro_is_latest_section_content_product_category_enable'
) ) );
