<?php
/**
 * partner Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add partner section
$wp_customize->add_section( 'web_artist_pro_partner_section', array(
	'title'             => esc_html__( 'Partners','web-artist-pro' ),
	'description'       => esc_html__( 'Partners Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// partner content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[partner_section_enable]', array(
	'default'			=> 	$options['partner_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[partner_section_enable]', array(
	'label'             => esc_html__( 'partner Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_partner_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );


// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[partner_count]', array(
	'default'          	=> $options['partner_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
	'validate_callback' => 'web_artist_pro_validate_partner_count',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[partner_count]', array(
	'label'             => esc_html__( 'Number of partners', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_partner_section',
	'active_callback'   => 'web_artist_pro_is_partner_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['partner_count']; $i++ ) :
	$wp_customize->add_setting( 'web_artist_pro_theme_options[partner_image_' .$i. ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'web_artist_pro_theme_options[partner_image_' .$i. ']',
			array(
			'label'       		=> esc_html__( 'Partner Logo ', 'web-artist-pro').$i,
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'web-artist-pro' ), 146, 90 ),
			'section'     		=> 'web_artist_pro_partner_section',
			'active_callback'	=> 'web_artist_pro_is_partner_section_enable',
	) ) );

	// partner btn link setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[partner_url_' .$i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[partner_url_' .$i. ']', array(
		'label'           	=> esc_html__( 'Partner Url ', 'web-artist-pro' ).$i,
		'section'        	=> 'web_artist_pro_partner_section',
		'active_callback' 	=> 'web_artist_pro_is_partner_section_enable',
		'type'				=> 'url',
	) );

endfor;
