<?php
/**
 * Popular Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */



// Add Popular section
$wp_customize->add_section( 'web_artist_pro_popular_section', array(
	'title'             => esc_html__( 'Popular','web-artist-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// Popular content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[popular_section_enable]', array(
	'default'			=> 	$options['popular_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[popular_section_enable]', array(
	'label'             => esc_html__( 'Popular Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_popular_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// popular title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[popular_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[popular_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_popular_section',
	'active_callback' 	=> 'web_artist_pro_is_popular_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[popular_title]', array(
		'selector'            => '#popular .section-header-wrapper h2.section-title',
		'settings'            => 'web_artist_pro_theme_options[popular_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_popular_title_partial',
    ) );
}

if ( $options['home_layout'] == 'default-design' ) {
	// popular btn_title setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[popular_btn_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['popular_btn_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[popular_btn_title]', array(
		'label'           	=> esc_html__( 'Button Label', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_popular_section',
		'active_callback' 	=> 'web_artist_pro_is_popular_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[popular_btn_title]', array(
			'selector'            => '#popular .wrapper a.btn',
			'settings'            => 'web_artist_pro_theme_options[popular_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'web_artist_pro_popular_btn_title_partial',
	    ) );
	}

	// popular btn_url setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[popular_btn_url]', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[popular_btn_url]', array(
		'label'           	=> esc_html__( 'Button Url', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_popular_section',
		'active_callback' 	=> 'web_artist_pro_is_popular_section_enable',
		'type'				=> 'url',
	) );

	// popular posts drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[popular_hr]', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Customize_Horizontal_Line( $wp_customize, 'web_artist_pro_theme_options[popular_hr]', array(
		'type'				=> 'hr',
		'section'           => 'web_artist_pro_popular_section',
		'active_callback'	=> 'web_artist_pro_is_popular_section_enable',
	) ) );
}



	/* post Category and product category Content Type Options*/
for ( $i = 1; $i <= 6; $i++ ) :
	if ( $options['home_layout'] == 'default-design' ) {
		$wp_customize->add_setting(  'web_artist_pro_theme_options[popular_content_product_category_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) ) ;

		$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[popular_content_product_category_' . $i . ']', array(
			'label'           => sprintf( esc_html__( 'Select Product Category %d', 'web-artist-pro' ), $i ),
			'section'           => 'web_artist_pro_popular_section',
			'taxonomy'			=> 'product_cat',
			'type'              => 'dropdown-taxonomies',
			'active_callback'	=> 'web_artist_pro_is_popular_section_enable'
		) ) );
	}else{
		$wp_customize->add_setting(  'web_artist_pro_theme_options[popular_content_category_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) ) ;

		$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[popular_content_category_' . $i . ']', array(
			'label'           => sprintf( esc_html__( 'Select Category %d', 'web-artist-pro' ), $i ),
			'section'           => 'web_artist_pro_popular_section',
			'taxonomy'			=> 'cat',
			'type'              => 'dropdown-taxonomies',
			'active_callback'	=> 'web_artist_pro_is_popular_section_enable'
		) ) );
	}


endfor;
