<?php
/**
 * reason Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add reason section
$wp_customize->add_section( 'web_artist_pro_reason_section', array(
	'title'             => esc_html__( 'Reason','web-artist-pro' ),
	'description'       => esc_html__( 'Reason Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// reason content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[reason_section_enable]', array(
	'default'			=> 	$options['reason_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[reason_section_enable]', array(
	'label'             => esc_html__( 'reason Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_reason_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );


// reason content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[reason_content_type]', array(
	'default'          	=> $options['reason_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[reason_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_reason_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_reason_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'web-artist-pro' ),
	),
) );

// reason pages drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[reason_content_page]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_page',
) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[reason_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_reason_section',
	'choices'			=> web_artist_pro_page_choices(),
	'active_callback'	=> 'web_artist_pro_is_reason_section_content_page_enable',
) ) );

// reason posts drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[reason_content_post]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_page',
) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[reason_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_reason_section',
	'choices'			=> web_artist_pro_post_choices(),
	'active_callback'	=> 'web_artist_pro_is_reason_section_content_post_enable',
) ) );

// reason title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[reason_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['reason_title'],
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[reason_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_reason_section',
	'active_callback' 	=> 'web_artist_pro_is_reason_section_content_custom_enable',
	'type'				=> 'text',
) );



// reason description setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[reason_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['reason_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[reason_description]', array(
	'label'           	=> esc_html__( 'Description', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_reason_section',
	'active_callback' 	=> 'web_artist_pro_is_reason_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// reason image setting and control.
$wp_customize->add_setting( 'web_artist_pro_theme_options[reason_image]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'web_artist_pro_theme_options[reason_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'web-artist-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'web-artist-pro' ), 512, 520 ),
		'section'     		=> 'web_artist_pro_reason_section',
		'active_callback'	=> 'web_artist_pro_is_reason_section_content_custom_enable',
) ) );
