<?php
/**
 * release Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add release section
$wp_customize->add_section( 'web_artist_pro_release_section', array(
	'title'             => esc_html__( 'Release','web-artist-pro' ),
	'description'       => esc_html__( 'Release Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// release content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[release_section_enable]', array(
	'default'			=> 	$options['release_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[release_section_enable]', array(
	'label'             => esc_html__( 'release Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_release_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// release title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[release_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['release_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[release_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_release_section',
	'active_callback' 	=> 'web_artist_pro_is_release_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[release_title]', array(
		'selector'            => '#recent .wrapper h2.section-title',
		'settings'            => 'web_artist_pro_theme_options[release_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_release_title_partial',
    ) );
}

if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'second-design' ) {
	$wp_customize->add_setting( 'web_artist_pro_theme_options[release_sub_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['release_sub_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[release_sub_title]', array(
		'label'           	=> esc_html__( 'Sub Title', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_release_section',
		'active_callback' 	=> 'web_artist_pro_is_release_section_enable',
		'type'				=> 'text',
	) );
}


// release btn title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[release_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['release_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[release_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_release_section',
	'active_callback' 	=> 'web_artist_pro_is_release_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[release_btn_title]', array(
		'selector'            => '#recent div.section-header-wrapper a.btn',
		'settings'            => 'web_artist_pro_theme_options[release_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_release_btn_title_partial',
    ) );
}


$wp_customize->add_setting( 'web_artist_pro_theme_options[release_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[release_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_release_section',
	'active_callback' 	=> 'web_artist_pro_is_release_section_enable',
	'type'				=> 'url',
) );

// release content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[release_content_type]', array(
	'default'          	=> $options['release_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[release_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_release_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_release_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'category' 	=> esc_html__( 'Category', 'web-artist-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[release_count]', array(
	'default'          	=> $options['release_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
	'validate_callback' => 'web_artist_pro_validate_release_count',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[release_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_release_section',
	'active_callback'   => 'web_artist_pro_is_release_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['release_count']; $i++ ) :
	// release pages drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[release_content_page_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[release_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_release_section',
		'choices'			=> web_artist_pro_page_choices(),
		'active_callback'	=> 'web_artist_pro_is_release_section_content_page_enable',
	) ) );

	// release posts drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[release_content_post_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[release_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_release_section',
		'choices'			=> web_artist_pro_post_choices(),
		'active_callback'	=> 'web_artist_pro_is_release_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[release_content_category]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[release_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_release_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'web_artist_pro_is_release_section_content_category_enable'
) ) );

