<?php
/**
* Slider Section options
*
* @package Theme Palace
* @subpackage Web Artist
* @since Web Artist 1.0.0
*/

// Add Slider section
$wp_customize->add_section( 'web_artist_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','web-artist-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_slider_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
	) ) );

// Slider Autoplay enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Slider Autoplay', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_slider_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
	'active_callback' 	=> 'web_artist_pro_is_slider_section_enable',
	) ) );

if ( $options['home_layout'] == 'default-design' ) {
	// Slider search enable control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_search_enable]', array(
		'default'			=> 	$options['slider_search_enable'],
		'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
		) );

	$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[slider_search_enable]', array(
		'label'             => esc_html__( 'Slider Search Enable', 'web-artist-pro' ),
		'section'           => 'web_artist_pro_slider_section',
		'on_off_label' 		=> web_artist_pro_switch_options(),
		'active_callback' 	=> 'web_artist_pro_is_slider_section_enable',
		) ) );
}


if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'seventh-design' ) {
	// Slider subtitle setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_readmore_text]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_readmore_text'],
		) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[slider_readmore_text]', array(
		'label'           	=> esc_html__( 'Read More Text', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_slider_section',
		'active_callback' 	=> 'web_artist_pro_is_slider_section_enable',
		'type'				=> 'text',
		) );

	$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_excerpt]', array(
		'sanitize_callback' => 'absint',
		'default'			=> $options['slider_excerpt'],
		) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[slider_excerpt]', array(
		'label'           	=> esc_html__( 'Excerpt Length', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_slider_section',
		'active_callback' 	=> 'web_artist_pro_is_slider_section_enable',
		'type'				=> 'number',
		) );
}

// Slider content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
	) );

$wp_customize->add_control( 'web_artist_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'category' 	=> esc_html__( 'Category', 'web-artist-pro' ),
		),
	) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
	'validate_callback' => 'web_artist_pro_validate_slider_count',
	) );

$wp_customize->add_control( 'web_artist_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_slider_section',
	'active_callback'   => 'web_artist_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'fifth-design' ) {
	// Slider subtitle setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_subtitle_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_subtitle'],
		) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[slider_subtitle_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Sub Title %d', 'web-artist-pro' ), $i ),
		'section'        	=> 'web_artist_pro_slider_section',
		'active_callback' 	=> 'web_artist_pro_is_slider_section_enable',
		'type'				=> 'text',
		) );
}


// slider pages drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_content_page_' . $i . ']', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'web-artist-pro' ), $i ),
	'section'           => 'web_artist_pro_slider_section',
	'choices'			=> web_artist_pro_page_choices(),
	'active_callback'	=> 'web_artist_pro_is_slider_section_content_page_enable',
	) ) );

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'web-artist-pro' ), $i ),
	'section'           => 'web_artist_pro_slider_section',
	'choices'			=> web_artist_pro_post_choices(),
	'active_callback'	=> 'web_artist_pro_is_slider_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'web_artist_pro_is_slider_section_content_category_enable'
	) ) );

