<?php
/**
 * team Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add team section
$wp_customize->add_section( 'web_artist_pro_team_section', array(
	'title'             => esc_html__( 'Team','web-artist-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// team content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'team Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_team_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// team title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_team_section',
	'active_callback' 	=> 'web_artist_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[team_title]', array(
		'selector'            => '#recent .wrapper h2.section-title',
		'settings'            => 'web_artist_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_team_title_partial',
    ) );
}

if ( $options['home_layout'] == 'fourth-design' ) {
	// team btn title setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[team_sub_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['team_sub_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[team_sub_title]', array(
		'label'           	=> esc_html__( 'Button Label', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_team_section',
		'active_callback' 	=> 'web_artist_pro_is_team_section_enable',
		'type'				=> 'text',
	) );
}



// team content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'category' 	=> esc_html__( 'Category', 'web-artist-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_team_section',
	'active_callback'   => 'web_artist_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :


	$wp_customize->add_setting( 'web_artist_pro_theme_options[team_social_'. $i .']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_links'
		) );

	$wp_customize->add_control( new Web_Artist_Pro_Multi_Input_Custom_Control( $wp_customize, 'web_artist_pro_theme_options[team_social_'. $i .']',
		array(
			'label'       	  => sprintf( esc_html__( 'Social Links %d', 'web-artist-pro' ), $i ),
			'button_text'     => sprintf( esc_html__( 'Add More Social Link', 'web-artist-pro' ), $i ),
			'section'         => 'web_artist_pro_team_section',
			'active_callback' => 'web_artist_pro_is_team_section_enable',
			'type'			  => 'multi-input'
			) ) );

	$wp_customize->add_setting( 'web_artist_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Team Position %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_team_section',
		'type' 				=> 'text',
		'active_callback'	=> 'web_artist_pro_is_team_section_enable',
	) ) );


	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_team_section',
		'choices'			=> web_artist_pro_page_choices(),
		'active_callback'	=> 'web_artist_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_team_section',
		'choices'			=> web_artist_pro_post_choices(),
		'active_callback'	=> 'web_artist_pro_is_team_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'web_artist_pro_is_team_section_content_category_enable'
) ) );

