<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'web_artist_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','web-artist-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'web-artist-pro' ),
	'panel'             => 'web_artist_pro_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_testimonial_section',
	'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

if($options['home_layout'] == 'seventh-design'){
		
	// testimonial title setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_subtitle]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['testimonial_subtitle'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_subtitle]', array(
		'label'           	=> esc_html__( 'Sub Title', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_testimonial_section',
		'active_callback' 	=> 'web_artist_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[testimonial_subtitle]', array(
			'selector'            => '#testimonial .section-header  p',
			'settings'            => 'web_artist_pro_theme_options[testimonial_subtitle]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'web_artist_pro_testimonial_subtitle_partial',
		) );
	}

}
// testimonial title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_testimonial_section',
	'active_callback' 	=> 'web_artist_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[testimonial_title]', array(
		'selector'            => '#client h2.section-title',
		'settings'            => 'web_artist_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'web_artist_pro_testimonial_title_partial',
    ) );
}

$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_excerpt]', array(
	'sanitize_callback' => 'adsint',
	'default'			=> $options['testimonial_excerpt'],
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_excerpt]', array(
	'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
	'section'        	=> 'web_artist_pro_testimonial_section',
	'active_callback' 	=> 'web_artist_pro_is_testimonial_section_enable',
	'type'				=> 'number',
) );


if ( $options['home_layout'] == 'default-design' ) {
	// testimonial subtitle setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_button]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['testimonial_button'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_button]', array(
		'label'           	=> esc_html__( 'Button', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_testimonial_section',
		'active_callback' 	=> 'web_artist_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[testimonial_button]', array(
			'selector'            => '#client .wrapper .read-more a.btn-fill',
			'settings'            => 'web_artist_pro_theme_options[testimonial_button]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'web_artist_pro_testimonial_button_partial',
	    ) );
	}

	// testimonial btn link setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_btn_link]', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_btn_link]', array(
		'label'           	=> esc_html__( 'Button Link', 'web-artist-pro' ),
		'section'        	=> 'web_artist_pro_testimonial_section',
		'active_callback' 	=> 'web_artist_pro_is_testimonial_section_enable',
		'type'				=> 'url',
	) );

}

// testimonial image setting and control.
$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_bg_image]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'web_artist_pro_theme_options[testimonial_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'web-artist-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'web-artist-pro' ), 512, 520 ),
		'section'     		=> 'web_artist_pro_testimonial_section',
		'active_callback'	=> 'web_artist_pro_is_testimonial_section_enable',
) ) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'web_artist_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
		'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
		'category' 	=> esc_html__( 'Category', 'web-artist-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
	'validate_callback' => 'web_artist_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'web-artist-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_testimonial_section',
	'active_callback'   => 'web_artist_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'web_artist_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'web-artist-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
	'section'           => 'web_artist_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'web_artist_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_testimonial_section',
		'choices'			=> web_artist_pro_page_choices(),
		'active_callback'	=> 'web_artist_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'web-artist-pro' ), $i ),
		'section'           => 'web_artist_pro_testimonial_section',
		'choices'			=> web_artist_pro_post_choices(),
		'active_callback'	=> 'web_artist_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'web-artist-pro' ), $i ),
		'section'        	=> 'web_artist_pro_testimonial_section',
		'active_callback' 	=> 'web_artist_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );



	// testimonial description setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'web-artist-pro' ), $i ),
		'section'        	=> 'web_artist_pro_testimonial_section',
		'active_callback' 	=> 'web_artist_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'web_artist_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'web_artist_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'web-artist-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'web-artist-pro' ), 200, 200 ),
			'section'     		=> 'web_artist_pro_testimonial_section',
			'active_callback'	=> 'web_artist_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'web_artist_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'web-artist-pro' ), $i ),
		'section'        	=> 'web_artist_pro_testimonial_section',
		'active_callback' 	=> 'web_artist_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'web_artist_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Web_Artist_Pro_Customize_Horizontal_Line( $wp_customize, 'web_artist_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'web_artist_pro_testimonial_section',
			'active_callback' => 'web_artist_pro_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;


