<?php
/**
* Topic Section options
*
* @package Theme Palace
* @subpackage Web Artist
* @since Web Artist 1.0.0
*/

// Add topic section
$wp_customize->add_section( 'web_artist_pro_topic_section', array(
'title'             => esc_html__( 'Topic','web-artist-pro' ),
'description'       => esc_html__( 'Topic Section options.', 'web-artist-pro' ),
'panel'             => 'web_artist_pro_front_page_panel',
) );

// topic content enable control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_section_enable]', array(
'default'			=> 	$options['topic_section_enable'],
'sanitize_callback' => 'web_artist_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Web_Artist_Pro_Switch_Control( $wp_customize, 'web_artist_pro_theme_options[topic_section_enable]', array(
'label'             => esc_html__( 'Topic Section Enable', 'web-artist-pro' ),
'section'           => 'web_artist_pro_topic_section',
'on_off_label' 		=> web_artist_pro_switch_options(),
) ) );

// topic title setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_title]', array(
'sanitize_callback' => 'sanitize_text_field',
'default'			=> $options['topic_title'],
'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[topic_title]', array(
'label'           	=> esc_html__( 'Title', 'web-artist-pro' ),
'section'        	=> 'web_artist_pro_topic_section',
'active_callback' 	=> 'web_artist_pro_is_topic_section_enable',
'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
$wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[topic_title]', array(
'selector'            => '#topics div.wrapper .section-header h2.section-title',
'settings'            => 'web_artist_pro_theme_options[topic_title]',
'container_inclusive' => false,
'fallback_refresh'    => true,
'render_callback'     => 'web_artist_pro_topic_title_partial',
) );
}

// topic button setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_button]', array(
'sanitize_callback' => 'sanitize_text_field',
'default'			=> $options['topic_button'],
'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[topic_button]', array(
'label'           	=> esc_html__( 'Button text', 'web-artist-pro' ),
'section'        	=> 'web_artist_pro_topic_section',
'active_callback' 	=> 'web_artist_pro_is_topic_section_enable',
'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
$wp_customize->selective_refresh->add_partial( 'web_artist_pro_theme_options[topic_button]', array(
'selector'            => '#topics a.btn',
'settings'            => 'web_artist_pro_theme_options[topic_button]',
'container_inclusive' => false,
'fallback_refresh'    => true,
'render_callback'     => 'web_artist_pro_topic_button_partial',
) );
}

// hero_content btn link setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_button_url]', array(
'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[topic_button_url]', array(
'label'           	=> esc_html__( 'Button Link', 'web-artist-pro' ),
'section'        	=> 'web_artist_pro_topic_section',
'active_callback' 	=> 'web_artist_pro_is_topic_section_enable',
'type'				=> 'url',
) );

// topic column type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_column]', array(
'default'          	=> $options['topic_column'],
'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[topic_column]', array(
'label'             => esc_html__( 'Column', 'web-artist-pro' ),
'section'           => 'web_artist_pro_topic_section',
'type'				=> 'select',
'active_callback' 	=> 'web_artist_pro_is_topic_section_enable',
'choices'			=> array( 
'col-2' 		=> esc_html__( 'Two Column', 'web-artist-pro' ),
'col-3' 		=> esc_html__( 'Three Column', 'web-artist-pro' ),
'col-4' 		=> esc_html__( 'Four Column', 'web-artist-pro' ),
),
) );

// topic content type control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_content_type]', array(
'default'          	=> $options['topic_content_type'],
'sanitize_callback' => 'web_artist_pro_sanitize_select',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[topic_content_type]', array(
'label'             => esc_html__( 'Content Type', 'web-artist-pro' ),
'section'           => 'web_artist_pro_topic_section',
'type'				=> 'select',
'active_callback' 	=> 'web_artist_pro_is_topic_section_enable',
'choices'			=> array( 
'page' 		=> esc_html__( 'Page', 'web-artist-pro' ),
'post' 		=> esc_html__( 'Post', 'web-artist-pro' ),
'category' 	=> esc_html__( 'Category', 'web-artist-pro' ),
),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_count]', array(
'default'          	=> $options['topic_count'],
'sanitize_callback' => 'web_artist_pro_sanitize_number_range',
'validate_callback' => 'web_artist_pro_validate_topic_count',
) );

$wp_customize->add_control( 'web_artist_pro_theme_options[topic_count]', array(
'label'             => esc_html__( 'Number of Topic', 'web-artist-pro' ),
'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'web-artist-pro' ),
'section'           => 'web_artist_pro_topic_section',
'active_callback'   => 'web_artist_pro_is_topic_section_enable',
'type'				=> 'number',
'input_attrs'		=> array(
'min'	=> 2,
'max'	=> 12,
'style' => 'width: 100px;'
),
) );

for ( $i = 1; $i <= $options['topic_count']; $i++ ) :

// topic note control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_content_icon_' . $i . ']', array(
'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Web_Artist_Pro_Icon_Picker( $wp_customize, 'web_artist_pro_theme_options[topic_content_icon_' . $i . ']', array(
'label'             => sprintf( esc_html__( 'Select Icon %d', 'web-artist-pro' ), $i ),
'section'           => 'web_artist_pro_topic_section',
'active_callback'	=> 'web_artist_pro_is_topic_section_enable',
) ) );

// topic pages drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_content_page_' . $i . ']', array(
'sanitize_callback' => 'web_artist_pro_sanitize_page',
) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[topic_content_page_' . $i . ']', array(
'label'             => sprintf( esc_html__( 'Select Page %d', 'web-artist-pro' ), $i ),
'section'           => 'web_artist_pro_topic_section',
'choices'			=> web_artist_pro_page_choices(),
'active_callback'	=> 'web_artist_pro_is_topic_section_content_page_enable',
) ) );

// topic posts drop down chooser control and setting
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_content_post_' . $i . ']', array(
'sanitize_callback' => 'web_artist_pro_sanitize_page',
) );

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Chooser( $wp_customize, 'web_artist_pro_theme_options[topic_content_post_' . $i . ']', array(
'label'             => sprintf( esc_html__( 'Select Post %d', 'web-artist-pro' ), $i ),
'section'           => 'web_artist_pro_topic_section',
'choices'			=> web_artist_pro_post_choices(),
'active_callback'	=> 'web_artist_pro_is_topic_section_content_post_enable',
) ) );

// topic hr setting and control
$wp_customize->add_setting( 'web_artist_pro_theme_options[topic_hr_'. $i .']', array(
'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Web_Artist_Pro_Customize_Horizontal_Line( $wp_customize, 'web_artist_pro_theme_options[topic_hr_'. $i .']',
array(
'section'         => 'web_artist_pro_topic_section',
'active_callback' => 'web_artist_pro_is_topic_section_content_seperator_enable',
'type'			  => 'hr'
) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'web_artist_pro_theme_options[topic_content_category]', array(
'sanitize_callback' => 'web_artist_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Web_Artist_Pro_Dropdown_Taxonomies_Control( $wp_customize,'web_artist_pro_theme_options[topic_content_category]', array(
'label'             => esc_html__( 'Select Category', 'web-artist-pro' ),
'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'web-artist-pro' ),
'section'           => 'web_artist_pro_topic_section',
'type'              => 'dropdown-taxonomies',
'active_callback'	=> 'web_artist_pro_is_topic_section_content_category_enable'
) ) );
