<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
if ( class_exists('WooCommerce') ) {
    function web_artist_pro_product_owner_choices() {
        $owners = get_terms( 'pa_owner' );
        $choices = array();
        if (taxonomy_exists( 'pa_owner' )) {
            $choices[0] = esc_html__( '--Select--', 'web-artist-pro' );
            foreach ( $owners as $owner ) {
              $choices[ $owner->term_id ] = $owner->name;
            }
        }
 
        return  $choices;
        
    }
}

if ( ! function_exists( 'web_artist_pro_latest_release_content_type' ) ) :
    /**
     * Latest Release Options
     * @return array site latest_release options
     */
    function web_artist_pro_latest_release_content_type() {
        $web_artist_pro_latest_release_content_type = array(
            'page'      => esc_html__( 'Page', 'web-artist-pro' ),
            'post'      => esc_html__( 'Post', 'web-artist-pro' ),
            'category'  => esc_html__( 'Category', 'web-artist-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $web_artist_pro_latest_release_content_type = array_merge( $web_artist_pro_latest_release_content_type, array(
                'product'   => esc_html__( 'Product', 'web-artist-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'web-artist-pro' ),
                ) );
        }

        $output = apply_filters( 'web_artist_pro_latest_release_content_type', $web_artist_pro_latest_release_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'web_artist_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function web_artist_pro_event_content_type() {
        $web_artist_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'web-artist-pro' ),
            'post'      => esc_html__( 'Post', 'web-artist-pro' ),
            'category'  => esc_html__( 'Category', 'web-artist-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $web_artist_pro_event_content_type = array_merge( $web_artist_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'web-artist-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'web-artist-pro' ),
                ) );
        }

        $output = apply_filters( 'web_artist_pro_event_content_type', $web_artist_pro_event_content_type );


        return $output;
    }
endif;

function web_artist_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'web-artist-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function web_artist_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'web-artist-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function web_artist_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'web-artist-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function web_artist_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'web-artist-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of audio for post choices.
 * @return Array Array of post ids and name.
 */
function web_artist_pro_audio_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'attachment', 'post_mime_type' => 'audio' ) );
    $choices = array();
    $choices[0] = esc_html__( '--None--', 'web-artist-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'web_artist_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function web_artist_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'web-artist-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'web-artist-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'web-artist-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'web-artist-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'web-artist-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'web-artist-pro' ),
        );

        $output = apply_filters( 'web_artist_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'web_artist_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function web_artist_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'web-artist-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'web-artist-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'web-artist-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'web-artist-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'web-artist-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'web-artist-pro' ),
        );

        $output = apply_filters( 'web_artist_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'web_artist_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function web_artist_pro_site_layout() {
        $web_artist_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'web_artist_pro_site_layout', $web_artist_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'web_artist_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function web_artist_pro_selected_sidebar() {
        $web_artist_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'web-artist-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'web-artist-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'web-artist-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'web-artist-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'web-artist-pro' ),
        );

        $output = apply_filters( 'web_artist_pro_selected_sidebar', $web_artist_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'web_artist_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function web_artist_pro_global_sidebar_position() {
        $web_artist_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'web_artist_pro_global_sidebar_position', $web_artist_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'web_artist_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function web_artist_pro_sidebar_position() {
        $web_artist_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'web_artist_pro_sidebar_position', $web_artist_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'web_artist_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function web_artist_pro_pagination_options() {
        $web_artist_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'web-artist-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'web-artist-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'web-artist-pro' ),
        );

        $output = apply_filters( 'web_artist_pro_pagination_options', $web_artist_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function web_artist_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'web-artist-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'web-artist-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'web-artist-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'web-artist-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'web-artist-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'web-artist-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'web-artist-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'web-artist-pro' ),
        );
        return apply_filters( 'web_artist_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'web_artist_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function web_artist_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'web-artist-pro' ),
            'off'       => esc_html__( 'Disable', 'web-artist-pro' )
        );
        return apply_filters( 'web_artist_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'web_artist_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function web_artist_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'web-artist-pro' ),
            'off'       => esc_html__( 'No', 'web-artist-pro' )
        );
        return apply_filters( 'web_artist_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'web_artist_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function web_artist_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Main Slider', 'web-artist-pro' ),
            'topic'    => esc_html__( 'Topic', 'web-artist-pro' ),
            'product'   => esc_html__( 'Product', 'web-artist-pro' ),
            'service'   => esc_html__( 'Services', 'web-artist-pro' ),
            'artisan'   => esc_html__( 'Artisan', 'web-artist-pro' ),
            'cta'       => esc_html__( 'Call to Action', 'web-artist-pro' ),
            'popular' => esc_html__( 'Popular', 'web-artist-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'web-artist-pro' ),
            'blog'      => esc_html__( 'Blog', 'web-artist-pro' ),
        );
        return apply_filters( 'web_artist_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'web_artist_pro_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
        function web_artist_pro_product_content_type() {

            if ( class_exists( 'WooCommerce' ) ) {

                $web_artist_pro_product_content_type = array(
                    'product'   => esc_html__( 'Product', 'web-artist-pro' ),
                    'product-category'   => esc_html__( 'Product Category', 'web-artist-pro' ),
                    'recent'    => esc_html__( 'Recent', 'web-artist-pro' ),
                    );
                $output = apply_filters( 'web_artist_pro_product_content_type', $web_artist_pro_product_content_type );

                return $output;
            }
        }
endif;

if ( class_exists('WooCommerce') ) {
    function web_artist_pro_advance_product_search(){
    ?>
        <form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
            <p><input type="search" name="s" placeholder="<?php echo esc_attr__( 'Search Products...', 'web-artist-pro' ); ?>"></p>

            <p>
                <select name="product_cat">
                    <option value="0" selected="selected"><?php echo esc_html__( 'Choose a Category', 'web-artist-pro' ); ?></option>
                    <?php 
                        $categoties = get_terms( 'product_cat' );
                        foreach ($categoties as $cat): 
                    ?>
                        <option class="level-0" value="<?php echo esc_attr( $cat->slug ) ?>">    <?php echo $cat->name ; ?>
                        </option>
                    <?php endforeach ?>
                </select>
            </p>
            <?php if ( taxonomy_exists( 'pa_location' ) ): ?>
                <p>
                    <select name="pa_location" >
                        <option value="0" selected="selected"><?php echo esc_html__( 'Choose a Location', 'web-artist-pro' ); ?></option>
                        <?php 
                            $locations = get_terms( 'pa_location' );
                          foreach ($locations as $location): 
                        ?>
                            <option class="level-0" value="<?php echo esc_attr( $location->slug ) ?>">    <?php echo $location->name ; ?>
                            </option>
                        <?php endforeach ?>
                        
                    </select>  
                </p>
            <?php endif ?>
            
            <input type="hidden" name="post_type" value="product" />
            <p><input type="submit" value="<?php echo esc_attr__( 'Search', 'web-artist-pro' ) ?>"></p>

        </form>
    <?php   
    }

    add_filter( 'get_product_search_form' , 'woo_custom_product_searchform' );
    function woo_custom_product_searchform( $form ) {
        ?>
       <form role="search" method="get" class="search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
            <label>
                <span class="screen-reader-text"><?php echo esc_html_x( 'Search for:', 'label', 'web-artist-pro' ); ?></span>
            </label>
            <input type="search" class="search-field" placeholder="<?php echo esc_attr_x( 'Search Product &hellip;', 'placeholder', 'web-artist-pro' ); ?>" value="<?php echo get_search_query(); ?>" name="s" />
            <button type="submit" class="search-submit"><?php echo web_artist_pro_get_svg( array( 'icon' => 'search' ) ); ?><span class="screen-reader-text"><?php echo esc_html_x( 'Search', 'submit button', 'web-artist-pro' ); ?></span></button>
            <input type="hidden" name="post_type" value="product" />
        </form>
    <?php }
}

