<?php
/**
 * about section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Web Artist 1.0.0
    */
    function web_artist_pro_add_about_section() {
    	$options = web_artist_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'web_artist_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        web_artist_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Web Artist 1.0.0
    * @param array $input about section details.
    */
    function web_artist_pro_get_about_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['image']        = ! empty( $options['about_image'] ) ? $options['about_image'] : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['content']   = get_the_content( );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'web_artist_pro_filter_about_section_details', 'web_artist_pro_get_about_section_details' );


if ( ! function_exists( 'web_artist_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Web Artist 1.0.0
   *
   */
   function web_artist_pro_render_about_section( $content_details = array() ) {
        $options = web_artist_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>

            <?php if ( $options['home_layout'] == 'sixth-design' ): ?>
                <div id="medical-about-us" class="relative page-section">
                    <div class="wrapper">
                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                <a href="#" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>"><?php echo esc_html( $content['title'] ) ?></a></h2>
                                </header>

                               <div class="entry-content">
                                    <p><?php echo wp_trim_words( wp_kses_post( $content['content']), $options['about_excerpt']  ); ?></p>
                                </div><!-- .entry-content -->

                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ) ?>" class="btn btn-fill">
                                        <?php echo esc_html( $options['about_btn_title'] ) ?>
                                    </a>
                                </div><!-- .read-more -->
                            </div><!-- .entry-container -->
                        </article>
                    </div><!-- .wrapper -->
                </div><!-- #medical-about-us -->
                <?php else: ?>
                <div id="<?php echo ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'seventh-design' ) ? 'business-' : '' ; ?>about-us" class="relative page-section">
                    <div class="wrapper">
                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                <a href="<?php echo esc_url( $content['url'] ) ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'seventh-design' ): ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>"><?php echo esc_html( $content['title'] ) ?></a></h2>
                                    </header>
                                <?php endif ?>
                                <?php if ( $options['home_layout'] == 'fifth-design' ): ?>
                                    <div class="section-header">
                                        <h2 class="section-title"><?php echo esc_html( $content['title'] ) ?></h2>
                                    </div>
                                <?php endif ?>
                                

                                <div class="entry-content">
                                    <p><?php echo wp_trim_words( wp_kses_post( $content['content']), $options['about_excerpt']  ); ?></p>
                                </div><!-- .entry-content -->

                                <?php if ( !empty( $options['about_btn_title'] ) ): ?>
                                    <div class="<?php echo ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'seventh-design' ) ? 'business-' : '' ; ?>read-more">
                                        <a href="<?php echo esc_url( $content['url'] ) ?>" <?php echo ( $options['home_layout'] == 'fifth-design' ) ? 'class="btn btn-fill"' : '' ; ?>>
                                            <?php echo esc_html( $options['about_btn_title'] ) ?>
                                        </a>
                                    </div><!-- .business-read-more -->
                                <?php endif ?>
                                
                            </div><!-- .entry-container -->
                        </article>
                    </div><!-- .wrapper -->
                </div><!-- #business-about-us -->   
            <?php endif ?>
        <?php endforeach; 
    }
endif;