<?php
/**
 * Artisan section
 *
 * This is the template for the content of artisan section
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_artisan_section' ) ) :
    /**
    * Add artisan section
    *
    *@since Web Artist 1.0.0
    */
    function web_artist_pro_add_artisan_section() {
    	$options = web_artist_pro_get_theme_options();
        // Check if artisan is enabled on frontpage
        $artisan_enable = apply_filters( 'web_artist_pro_section_status', true, 'artisan_section_enable' );

        if ( true !== $artisan_enable ) {
            return false;
        }
        // Get artisan section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_artisan_section_details', $section_details );

         if ( empty( $section_details ) || !class_exists('WooCommerce') ) {
            return;
        }

        // Render artisan section now.
        web_artist_pro_render_artisan_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_artisan_section_details' ) ) :
    /**
    * artisan section details.
    *
    * @since Web Artist 1.0.0
    * @param array $input artisan section details.
    */
    function web_artist_pro_get_artisan_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();

        // Content type.
        $artisan_content_type  = $options['artisan_content_type'];
        $artisan_count = ! empty( $options['artisan_count'] ) ? $options['artisan_count'] : 4;
        
        $content = array();
        $owner = array();
        for ( $i = 1; $i <= $artisan_count; $i++ ) {
            if ( ! empty( $options['artisan_content_owner_' . $i] ) ) :
                $owner[$i]['id'] = $options['artisan_content_owner_' . $i];
                $owner[$i]['slug'] = get_the_category( $options['artisan_content_owner_' . $i] );
                $owner[$i]['name'] = get_the_category_by_ID($options['artisan_content_owner_' . $i]);
                $owner[$i]['description'] = category_description($options['artisan_content_owner_' . $i]);
                $owner[$i]['url'] = get_category_link($options['artisan_content_owner_' . $i]);
            endif;
        }    
        array_push( $content, $owner );     
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// artisan section content details.
add_filter( 'web_artist_pro_filter_artisan_section_details', 'web_artist_pro_get_artisan_section_details' );


if ( ! function_exists( 'web_artist_pro_render_artisan_section' ) ) :
  /**
   * Start artisan section
   *
   * @return string artisan content
   * @since Web Artist 1.0.0
   *
   */
   function web_artist_pro_render_artisan_section( $content_details = array() ) {
        $options = web_artist_pro_get_theme_options();
        
        if ( empty( $content_details )   ) {
            return;
        } 
        ?>
        <div id="artisian" class="page-section">
            <div class="wrapper">
                <div class="section-header-wrapper clear">
                    <?php if( !empty( $options['artisan_title'] ) && !empty( $options['artisan_subtitle'] ) ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['artisan_title'] ); ?> <span><?php echo esc_html( $options['artisan_subtitle'] ); ?></span></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>
            </div><!-- .section-header-wrapper -->

            <div class="section-content">
                <?php for( $i = 1 ; $i <= count($content_details[0]) ; $i++ ) :  ?>

                    <article>
                        <header class="entry-header">
                            <img src="<?php echo esc_url( z_taxonomy_image_url( $content_details[0][$i]['id'] ) ) ; ?>" alt="<?php echo esc_html( $content_details[0][$i]['name'] ); ?>">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content_details[0][$i]['url'] ); ?>"><?php echo esc_html( $content_details[0][$i]['name'] ); ?></a></h2>
                            <ul class="post-categories">
                                <li>                             
                                    <?php echo wp_kses_post( $content_details[0][$i]['description'] ); ?>
                                </li>
                            </ul>

                            <span>

                            <?php 
                                $slug =strtolower(str_replace(" ","-", $content_details[0][$i]['name']));
                                $args = array(
                                    'post_type'      => 'product',
                                    'tax_query'      => array( 
                                    array(
                                        'taxonomy'        => 'pa_owner',
                                        'field'           => 'slug',
                                        'terms'           =>  $slug,
                                        'operator'        => 'IN',
                                    ),
                                )
                                );
                                $product_count = count( get_posts( $args ) );
                                echo esc_html( $product_count ); 
                                if ( $product_count > 1 ) {
                                    echo esc_html__( ' Products', 'web-artist-pro' );
                                }else{
                                    echo esc_html__( ' Product', 'web-artist-pro' );
                                }

                            ?>
                                
                            </span>

                        </header><!-- .entry-header -->

                        <div class="social-icons">
                            <ul>
                                <?php 
                                $artisan_socials = ! empty( $options['artisan_social_' . $i ] ) ? explode( '|', $options['artisan_social_' . $i ] ) : array(); 

                                foreach ( $artisan_socials as $artisan_social ) : ?>
                                <li>
                                    <a href="<?php echo esc_url( $artisan_social ); ?>"><?php echo web_artist_pro_return_social_icon( $artisan_social ); ?></a>
                                </li>
                                <?php endforeach; 
                                ?>
                            </ul>
                            
                        </div><!-- .social-icons -->

                        <div class="button">
                            <a href="<?php echo esc_url( $content_details[0][$i]['url'] ); ?>" class="btn btn-fill" tabindex="0"><?php echo esc_html__('Learn More', 'web-artist-pro'); ?></a>
                        </div><!-- .button -->
                    </article>

                    <?php endfor; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #artisian -->

    <?php }
endif;
       