<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Web Artist 1.0.0
    */
    function web_artist_pro_add_blog_section() {
    	$options = web_artist_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'web_artist_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        web_artist_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Web Artist 1.0.0
    * @param array $input blog section details.
    */
    function web_artist_pro_get_blog_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 3;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = get_the_content();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), array( 450, 250 ) ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'web_artist_pro_filter_blog_section_details', 'web_artist_pro_get_blog_section_details' );


if ( ! function_exists( 'web_artist_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Web Artist 1.0.0
   *
   */
   function web_artist_pro_render_blog_section( $content_details = array() ) {
        $options = web_artist_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];
        $column = ! empty( $options['blog_column'] ) ? $options['blog_column'] : 'col-3';
        $i = 1;
        if ( is_active_sidebar( 'blog-sidebar' ) ) {
            $sidebar_id = 'primary';
        }else{
            $sidebar_id = '';
        }
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if (  $options['home_layout'] == 'default-design' || $options['home_layout'] == 'fifth-design' ): ?>
            <div id="recent" class="page-section relative">
                <div class="wrapper">
                    <div class="section-header-wrapper clear">
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                        </div><!-- .section-header -->
                        <?php if ( ! empty( $options['blog_btn_title'] ) && ! empty( $options['blog_btn_url'] ) ) : ?>
                            <a href="<?php echo esc_url( $options['blog_btn_url'] ); ?>" class="btn"><?php echo esc_html( $options['blog_btn_title'] ); ?></a>
                        <?php endif; ?>
                    </div><!-- .section-header-wrapper -->

                    <div class="section-content <?php echo esc_attr( $column ); ?>">
                        <div class="archive-blog-wrapper clear">
                            
                            <?php foreach ( $content_details as $content ) : ?>

                            <article class="hentry">
                                <div class="post-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span>
                                            <?php web_artist_pro_posted_on( $content['id'] ); ?>
                                        </div><!-- .entry-meta -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo wp_trim_words( wp_kses_post( $content['excerpt']), $options['blog_excerpt']  ); ?>
                                                <a href="<?php echo esc_url( $content['url'] ); ?>">(<?php echo esc_html( $options['blog_btn_title'] ); ?>)</a>
                                            </p>

                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .post-wrapper -->
                            </article>

                        <?php endforeach; ?>

                        </div><!-- .archive-blog-wrapper -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
        <?php endif ?>
        <?php if ( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'seventh-design' ): ?>
            <div id="business-latest-posts" class="relative page-section">
                <div class="wrapper">
                    <div class="business-section-header">
                        <h2 class="business-section-title">
                            <?php echo esc_html( $options['blog_title'] ); ?>
                        </h2>
                        <p class="business-section-subtitle">
                            <?php echo esc_html( $options['blog_sub_title'] ); ?>
                        </p>
                    </div><!-- .business-section-header -->

                    <div class="business-section-content clear <?php echo esc_attr( $column ); ?>">
                        <?php foreach ($content_details as $content): ?>
                            <article class="has-post-thumbnail">
                                <div class="business-post-item">
                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p>
                                                <?php echo wp_trim_words( wp_kses_post( $content['excerpt']), $options['blog_excerpt']  ); ?>
                                            </p>
                                        </div><!-- .entry-content -->

                                        <div class="entry-meta clear">
                                            <?php web_artist_pro_posted_on( $content['id'] ); ?>
                                            <?php if ( !empty( $options['blog_btn_title'] ) ): ?>
                                                <span class="more-link"><a href="<?php echo esc_url( $content['url'] ); ?>">
                                                    <?php echo esc_html( $options['blog_btn_title'] ); ?>
                                                </a></span>
                                            <?php endif ?>
                                            
                                        </div><!-- .entry-meta -->
                                    </div><!-- .entry-container -->
                                </div><!-- .business-post-item -->
                            </article>
                        <?php endforeach ?>
                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #business-latest-posts -->
        <?php endif ?>
        <?php if ( $options['home_layout'] == 'sixth-design' ): ?>
            <div id="medical-news" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title">
                            <?php echo esc_html( $options['blog_title'] ); ?>
                        </h2>
                        <p class="section-subtitle">
                            <?php echo esc_html( $options['blog_sub_title'] ); ?>
                        </p>
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                        <?php foreach ($content_details as $content): ?>
                            <article>
                                <div class="medical-news-item">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                        <?php  
                                            $day = get_the_date( 'd', $content['id'] );
                                            $month = get_the_date( 'M', $content['id'] );
                                        ?>
                                        <div class="date"><?php echo esc_html($day) ?> <br><?php echo esc_html($month) ?></div>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>">
                                                <?php echo esc_html( $content['title'] ); ?>
                                            </a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p>
                                                <?php echo wp_trim_words( wp_kses_post( $content['excerpt']), $options['blog_excerpt']  ); ?>
                                            </p>
                                        </div><!-- .entry-content -->

                                        <?php if ( !empty($options['blog_btn_title']) ): ?>
                                            <div class="post-read-more">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>"> <?php echo esc_html( $options['blog_btn_title'] ); ?> </a>
                                            </div><!-- .post-read-more -->
                                        <?php endif ?>
                                        
                                    </div><!-- .entry-container -->
                                </div><!-- .medical-news-item -->
                            </article>
                        <?php endforeach ?>                        
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #medical-news -->
        <?php endif ?>
    <?php }
endif;