<?php
/**
 * course section
 *
 * This is the template for the content of course section
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_course_section' ) ) :
    /**
    * Add course section
    *
    *@since Web Artist 1.0.0
    */
    function web_artist_pro_add_course_section() {
        $options = web_artist_pro_get_theme_options();
        // Check if course is enabled on frontpage
        $course_enable = apply_filters( 'web_artist_pro_section_status', true, 'course_section_enable' );

        if ( true !== $course_enable ) {
            return false;
        }
        // Get course section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_course_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render course section now.
        web_artist_pro_render_course_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_course_section_details' ) ) :
    /**
    * course section details.
    *
    * @since Web Artist 1.0.0
    * @param array $input course section details.
    */
    function web_artist_pro_get_course_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();

        // Content type.
        $course_content_type  = $options['course_content_type'];
        $course_count = ! empty( $options['course_count'] ) ? $options['course_count'] : 3;
        
        $content = array();
        switch ( $course_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_page_' . $i] ) )
                        $page_ids[] = $options['course_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_post_' . $i] ) )
                        $post_ids[] = $options['course_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['course_content_category'] ) ? $options['course_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $course_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = get_the_content();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), array( 450, 250 ) ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// course section content details.
add_filter( 'web_artist_pro_filter_course_section_details', 'web_artist_pro_get_course_section_details' );


if ( ! function_exists( 'web_artist_pro_render_course_section' ) ) :
  /**
   * Start course section
   *
   * @return string course content
   * @since Web Artist 1.0.0
   *
   */
   function web_artist_pro_render_course_section( $content_details = array() ) {
        $options = web_artist_pro_get_theme_options();
        $column = ! empty( $options['course_column'] ) ? $options['course_column'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="courses-section" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title separator">
                            <?php echo esc_html( $options['course_title'] ) ?>
                        </h2>
                    </div><!-- .section-header -->

                    <!-- .supports col-1, col-2 and col-3 -->
                    <div class="section-content clear <?php echo esc_attr($column) ?>">
                        <?php $i=1; foreach ($content_details as $content): ?>
                            <article class="hentry">
                                <div class="courses-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ) ?>" class="featured-image-link"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>">
                                                <?php echo esc_html( $content['title'] ) ?>
                                            </a></h2>
                                        </header>
                                        <ul>
                                            <?php echo esc_html( $options['course_text_'.$i] ) ?>
                                        </ul>
                                    </div><!-- .entry-container -->
                                </div><!-- .courses-wrapper -->
                            </article>
                        <?php $i++; endforeach ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #courses-section --> 
    <?php }
endif;