<?php
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Web Artist Pro
 * @since Web Artist Pro 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Web Artist Pro 1.0.0
    */
    function web_artist_pro_add_gallery_section() {
        $options = web_artist_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'web_artist_pro_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        web_artist_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Web Artist Pro 1.0.0
    * @param array $input gallery section details.
    */
    function web_artist_pro_get_gallery_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();

        // Content type.
        $gallery_content_type   = $options['gallery_content_type'];
        $gallery_count          = ! empty( $options['gallery_count'] ) ? $options['gallery_count'] : 3;
        $content = array();
        switch ( $gallery_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_page_' . $i] ) ) :
                        $page_ids[] = $options['gallery_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_post_' . $i] ) ) :
                        $post_ids[] = $options['gallery_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
        $query = new WP_Query( $args );
        $i = 1;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['subtitle']  = ! empty( $options['subtitle'] ) ? $options['subtitle'] : '';
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url(  get_the_id(), array( 370, 285 ) ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'web_artist_pro_filter_gallery_section_details', 'web_artist_pro_get_gallery_section_details' );


if ( ! function_exists( 'web_artist_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Web Artist Pro 1.0.0
   *
   */
   function web_artist_pro_render_gallery_section( $content_details = array() ) {
       
       if ( empty( $content_details ) ) {
           return;
        }
        $options = web_artist_pro_get_theme_options();
        $gallery_subtitle   = ! empty( $options['gallery_subtitle'] ) ? $options['gallery_subtitle'] : '';
        $gallery_title      = ! empty( $options['gallery_title'] ) ? $options['gallery_title'] : '';

        ?>
        <div id="gallery-section" class="relative page-section">
            <div class="wrapper">
                <div class="business-section-header">
                    <h2 class="business-section-title"><?php echo esc_html($gallery_title); ?></h2>
                    <p class="business-section-subtitle"><?php echo esc_html($gallery_subtitle); ?></p>
                </div><!-- .business-section-header -->

                <div class="business-section-content clear col-3">
                    <?php foreach ($content_details as $content): ?>
                        <article><a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>"></a></article>
                <?php endforeach; ?>
                </div><!-- .business-section-content -->
            </div><!-- .wrapper -->
        </div><!-- #gallery-section -->

    <?php }
endif;
            