<?php
/**
* recent_latest section
*
* This is the template for the content of recent_latest section
*
* @package Theme Palace
* @subpackage Web Artist Pro
* @since Web Artist Pro 1.0.0
*/
if ( ! function_exists( 'web_artist_pro_add_latest_section' ) ) :
/**
* Add recent_latest section
*
*@since Web Artist Pro 1.0.0
*/
function web_artist_pro_add_latest_section() {
    $options = web_artist_pro_get_theme_options();
// Check if recent_latest is enabled on frontpage
    $latest_enable = apply_filters( 'web_artist_pro_section_status', true, 'latest_section_enable' );

    if ( true !== $latest_enable ) {
        return false;
    }
// Get recent_latest section details
    $section_details = array();
    $section_details = apply_filters( 'web_artist_pro_filter_latest_section_details', $section_details );

    if ( empty( $section_details ) || !class_exists('WooCommerce') ) {
            return;
        }
// Render recent_latest section now.
    web_artist_pro_render_latest_section( $section_details );
}
endif;

if ( ! function_exists( 'web_artist_pro_get_latest_section_details' ) ) :
/**
* recent_latest section details.
*
* @since Web Artist Pro 1.0.0
* @param array $input recent_latest section details.
*/
function web_artist_pro_get_latest_section_details( $input ) {
    $options = web_artist_pro_get_theme_options();

// Content type.
    $latest_content_type  = $options['latest_content_type'];     
    $latest_count = ! empty( $options['latest_count'] ) ? $options['latest_count'] : 3;

    $content = array();
    $content = array();
    switch ( $latest_content_type ) {

        case 'recent':
        $args = array(
            'post_type'             => 'product',
            'posts_per_page'        => $latest_count,
            'ignore_sticky_posts'   => true,
            );
        break;

        case 'product':
        $page_ids = array();

        for ( $i = 1; $i <= $latest_count; $i++ ) {
            if ( ! empty( $options['latest_content_product_' . $i] ) )
                $page_ids[] = $options['latest_content_product_' . $i];
        }

        $args = array(
            'post_type'         => 'product',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $latest_count ),
            'orderby'           => 'post__in',
            );
        break;
        
        case 'product-category':
        $cat_id = ! empty( $options['latest_content_product_category'] ) ? $options['latest_content_product_category'] : '';

        $args = array(
            'post_type'         => 'product',
            'posts_per_page'    => absint( $latest_count ),
            'tax_query'         => array(
                array(
                    'taxonomy'  => 'product_cat',
                    'field'     => 'id',
                    'terms'     => $cat_id
                    )
                ) );
        break;

        default:
        break;
    }

// Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = web_artist_pro_trim_content( 5 );
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), array( 330, 250 )) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// recent_latest section content details.
add_filter( 'web_artist_pro_filter_latest_section_details', 'web_artist_pro_get_latest_section_details' );


if ( ! function_exists( 'web_artist_pro_render_latest_section' ) ) :
/**
* Start recent_latest section
*
* @return string recent_latest content
* @since Web Artist Pro 1.0.0
*
*/
function web_artist_pro_render_latest_section( $content_details = array() ) {
    $options = web_artist_pro_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
    } ?>
    <div id="latest-products" class="relative page-section">
        <div class="wrapper">
            <div class="section-header">
                <p class="section-subtitle"><?php echo esc_html( $options['latest_sub_title'] ) ?></p>
                <h2 class="section-title"><?php echo esc_html( $options['latest_title'] ) ?></h2>
            </div><!-- .section-header -->

            <!-- supports col-1, col-2, col-3 and col-4 -->
            <div class="section-content clear">
                <ul class="products clear col-4">                        
                    <?php foreach ($content_details as $content): ?>
                        <li class="product">
                            <article class="hentry">
                                <div class="product-item-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']) ?>');">
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <h2 class="woocommerce-loop-product__title"><a href="<?php echo esc_url($content['url']) ?>"><?php echo esc_html($content['title']) ?></a></h2>

                                        <div class="product-meta">
                                            <div class="cat-links">
                                                <?php the_category() ?>       
                                            </div><!-- .cat-links -->
                                        </div><!-- .product-meta -->

                                        <span class="price"> 
                                            <ins><span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol"> <?php 
                                            $product = new WC_Product( $content['id'] );
                                            echo $product->get_price_html();
                                            ?></ins>
                                        </span><!-- .price -->

                                        <div class="button-actions">
                                            <a href="<?php echo esc_url($content['url']) ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php echo esc_html( $options['latest_button'] ) ?></a>   
                                        </div><!-- .button-actions -->  
                                    </div><!-- .entry-container -->
                                </div><!-- .product-item-wrapper -->
                            </article>
                        </li>
                    <?php endforeach ?>
                </ul>
            </div><!-- .section-content -->
        </div><!-- .wrapper -->
    </div><!-- #latest-products -->
    <?php }
    endif;