<?php
/**
 * Popular section
 *
 * This is the template for the content of popular section
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_popular_section' ) ) :
    /**
    * Add popular section
    *
    *@since Web Artist 1.0.0
    */
    function web_artist_pro_add_popular_section() {
    	$options = web_artist_pro_get_theme_options();
        // Check if popular is enabled on frontpage
        $popular_enable = apply_filters( 'web_artist_pro_section_status', true, 'popular_section_enable' );

        if ( true !== $popular_enable ) {
            return false;
        }
        // Get popular section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_popular_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular section now.
        web_artist_pro_render_popular_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_popular_section_details' ) ) :
    /**
    * popular section details.
    *
    * @since Web Artist 1.0.0
    * @param array $input popular section details.
    */
    function web_artist_pro_get_popular_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();
        $cat_id = array();

        for ( $i = 1; $i <= 6; $i++ ) {
            if ($options['home_layout'] == 'default-design' ) {
                if ( ! empty( $options['popular_content_product_category_' . $i ] ) )
                $cat_id[$i] = $options['popular_content_product_category_' . $i ];
            }else{
                if ( ! empty( $options['popular_content_category_' . $i ] ) )
                $cat_id[$i] = $options['popular_content_category_' . $i ];
            }
            
        }

        return $cat_id;
    }
endif;
// popular section content details.
add_filter( 'web_artist_pro_filter_popular_section_details', 'web_artist_pro_get_popular_section_details' );


if ( ! function_exists( 'web_artist_pro_render_popular_section' ) ) :
  /**
   * Start popular section
   *
   * @return string popular content
   * @since Web Artist 1.0.0
   *
   */
   function web_artist_pro_render_popular_section( $cat_id ) {
        $options = web_artist_pro_get_theme_options();

        if ( empty( $cat_id ) ) {
            return;
        } ?>
        <div id="popular" class="page-section">
            <div class="wrapper">
                <div class="section-header-wrapper clear">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['popular_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <?php if( !empty( $options['popular_btn_url'] ) && !empty( $options['popular_btn_title'] ) && $options['home_layout'] == 'default-design' ): ?>
                        <a href="<?php echo esc_url( $options['popular_btn_url'] ); ?>" class="btn"><?php echo esc_html( $options['popular_btn_title'] ); ?></a>
                    <?php endif; ?>
                </div><!-- .section-header-wrapper -->

                <div class="section-content grid">

                <?php foreach ( $cat_id as $id ) :
                    if ( $options['home_layout'] == 'default-design' ) {
                        $cat_name = ucfirst( get_term_by( 'id', $id, 'product_cat')->name);
                        $args = array(
                            'post_type' => 'product',
                            'product_cat' => $cat_name,
                            'posts_per_page' => -1,
                        );
                        $product_count = count( get_posts( $args ) );
                        $thumbnail_id = get_term_meta( $id, 'thumbnail_id', true );
                        $image = wp_get_attachment_url( $thumbnail_id );
                        $term_link = get_term_link( $id, 'product_cat' );
                    }else{
                        $cat_name = ucfirst( get_cat_name( $id ));
                        $image = z_taxonomy_image_url( $id );
                        $term_link = get_category_link( $id );
                    }
                
                ?>

                    <article class="grid-item">
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                            <div class="overlay"></div>
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url(  $term_link ) ; ?>"><?php echo esc_html( $cat_name ); ?></a></h2>
                                <?php if ( $options['home_layout'] == 'default-design' ): ?>
                                    <span>
                                        <?php 
                                        echo absint( $product_count );
                                        echo ($product_count < 2) ? ' product' : ' products';
                                         ?>
                                    </span>
                                <?php endif ?>
                                
                            </header>
                        </div><!-- .featured-image -->
                    </article>

                    <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #popular -->

    <?php }
endif;
        




        