<?php
/**
* Slider section
*
* This is the template for the content of slider section
*
* @package Theme Palace
* @subpackage Web Artist
* @since Web Artist 1.0.0
*/
if ( ! function_exists( 'web_artist_pro_add_slider_section' ) ) :
/**
* Add slider section
*
*@since Web Artist 1.0.0
*/
function web_artist_pro_add_slider_section() {
    $options = web_artist_pro_get_theme_options();
// Check if slider is enabled on frontpage
    $slider_enable = apply_filters( 'web_artist_pro_section_status', true, 'slider_section_enable' );

    if ( true !== $slider_enable ) {
        return false;
    }
// Get slider section details
    $section_details = array();
    $section_details = apply_filters( 'web_artist_pro_filter_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render slider section now.
    web_artist_pro_render_slider_section( $section_details );
}
endif;

if ( ! function_exists( 'web_artist_pro_get_slider_section_details' ) ) :
/**
* slider section details.
*
* @since Web Artist 1.0.0
* @param array $input slider section details.
*/
function web_artist_pro_get_slider_section_details( $input ) {
    $options = web_artist_pro_get_theme_options();

// Content type.
    $slider_content_type  = $options['slider_content_type'];
    $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;

    $content = array();
    switch ( $slider_content_type ) {

        case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $slider_count; $i++ ) {
            if ( ! empty( $options['slider_content_page_' . $i] ) )
                $page_ids[] = $options['slider_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $slider_count ),
            'orderby'           => 'post__in',
            );                    
        break;

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $slider_count; $i++ ) {
            if ( ! empty( $options['slider_content_post_' . $i] ) )
                $post_ids[] = $options['slider_content_post_' . $i];
        }
        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $slider_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $slider_count ),
            'cat'               => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }

// Run The Loop.
    $query = new WP_Query( $args );
    $i = 1;
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['content']   = get_the_content();
    $page_post['url']       = get_the_permalink();
    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
    $page_post['subtitle']  = ! empty( $options['slider_subtitle_' . $i] ) ? $options['slider_subtitle_' . $i] : '';

// Push to the main array.
    array_push( $content, $page_post );

    $i++;
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// slider section content details.
add_filter( 'web_artist_pro_filter_slider_section_details', 'web_artist_pro_get_slider_section_details' );


if ( ! function_exists( 'web_artist_pro_render_slider_section' ) ) :
/**
* Start slider section
*
* @return string slider content
* @since Web Artist 1.0.0
*
*/
function web_artist_pro_render_slider_section( $content_details = array() ) {
    $options = web_artist_pro_get_theme_options();
    $slider_content_type  = $options['slider_content_type'];
    $slider_autoplay    = ($options['slider_autoplay'] == true ) ? 'true' : 'false';

    if ( empty( $content_details ) ) {
        return;
    } ?>

    <?php if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'fifth-design' ): ?>
        <div id="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 2000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr($slider_autoplay); ?>, "draggable": true, "fade": true }'>
            <?php foreach ( $content_details as $content ) : ?>

                <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="featured-content-wrapper">
                            <header class="entry-header">
                                <span><?php echo esc_html($content['subtitle']); ?></span>
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header><!-- .entry- header -->

                            <?php if ( $options['home_layout'] == 'fifth-design' ): ?>
                                <div class="entry-content">
                                    <p><?php echo wp_trim_words( wp_kses_post( $content['content']), $options['slider_excerpt']  ); ?></p>
                                </div><!-- .entry-content-->

                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill">
                                        <?php echo esc_html( $options['slider_readmore_text'] ); ?>
                                        <svg viewBox="0 0 512 512">
                                            <path d="M511.189,259.954c1.649-3.989,0.731-8.579-2.325-11.627l-192-192
                                                c-4.237-4.093-10.99-3.975-15.083,0.262c-3.992,4.134-3.992,10.687,0,14.82l173.803,173.803H10.667
                                                C4.776,245.213,0,249.989,0,255.88c0,5.891,4.776,10.667,10.667,10.667h464.917L301.803,440.328
                                                c-4.237,4.093-4.355,10.845-0.262,15.083c4.093,4.237,10.845,4.354,15.083,0.262c0.089-0.086,0.176-0.173,0.262-0.262l192-192
                                                C509.872,262.42,510.655,261.246,511.189,259.954z"/>
                                            <path d="M309.333,458.546c-5.891,0.011-10.675-4.757-10.686-10.648c-0.005-2.84,1.123-5.565,3.134-7.571L486.251,255.88
                                                L301.781,71.432c-4.093-4.237-3.975-10.99,0.262-15.083c4.134-3.992,10.687-3.992,14.82,0l192,192
                                                c4.164,4.165,4.164,10.917,0,15.083l-192,192C314.865,457.426,312.157,458.546,309.333,458.546z"/>
                                            <path d="M501.333,266.546H10.667C4.776,266.546,0,261.771,0,255.88c0-5.891,4.776-10.667,10.667-10.667h490.667
                                                c5.891,0,10.667,4.776,10.667,10.667C512,261.771,507.224,266.546,501.333,266.546z"/>
                                        </svg>
                                    </a>
                                </div><!-- .read-more -->
                            <?php endif ?>
                            
                            <?php if ( $options['slider_search_enable'] && $options['home_layout'] == 'default-design' ) : ?>
                                <div class="entry-content">
                                    <div class="featured-search clear">
                                        <?php if ( class_exists('WooCommerce') ): ?>
                                            <?php web_artist_pro_advance_product_search(); ?>
                                        <?php endif ?>
                                    </div><!-- .featured-search -->
                                </div><!-- .entry-content-->
                            <?php endif; ?>
                        </div><!-- .featured-content-wrapper -->
                    </div><!-- .wrapper -->
                </article>

            <?php endforeach; ?>

        </div><!-- #featured-slider -->
    <?php endif ?>
    <?php if ( $options['home_layout'] == 'fourth-design' ||  $options['home_layout'] == 'seventh-design' ): ?>
        <div id="business-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo esc_attr($slider_autoplay); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>
            <?php foreach ( $content_details as $content ) : ?>
                <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="business-slider-wrapper">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_trim_words( wp_kses_post( $content['content']), $options['slider_excerpt']  ); ?></p>
                            </div><!-- .entry-content-->

                            <?php if ( !empty( $options['slider_readmore_text'] ) ): ?>
                                <div class="business-read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>">
                                        <?php echo esc_html( $options['slider_readmore_text'] ); ?>
                                    </a>
                                </div><!-- .business-read-more -->
                            <?php endif ?>
                            
                        </div><!-- .business-slider-wrapper -->
                    </div><!-- .wrapper -->
                </article>

            <?php endforeach; ?>    
        </div><!-- #featured-slider -->
    <?php endif ?>

    <?php if ( $options['home_layout'] == 'sixth-design' ): ?>
        <div id="medical-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo esc_attr($slider_autoplay); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>
            <?php foreach ( $content_details as $content ) : ?>
                <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="medical-slider-wrapper">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <?php echo esc_html( $content['title'] ); ?>
                                </a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_trim_words( wp_kses_post( $content['content']), $options['slider_excerpt']  ); ?></p>
                            </div><!-- .entry-content-->

                            <div class="medical-read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <?php echo esc_html( $options['slider_readmore_text'] ); ?>
                                </a>
                            </div><!-- .medical-read-more -->
                        </div><!-- .medical-slider-wrapper -->
                    </div><!-- .wrapper -->
                </article>
            <?php endforeach; ?>
        </div><!-- #business-slider -->
    <?php endif ?>
    <?php if ( $options['home_layout'] == 'second-design' ): ?>
        <div id="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 2000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr($slider_autoplay); ?>, "draggable": true, "fade": true }'>
            <?php foreach ($content_details as $content): ?>
                <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="featured-content-wrapper">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header><!-- .entry- header -->

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill"><?php echo esc_html( $options['slider_readmore_text'] ); ?>
                                </a>
                            </div><!-- .read-more -->
                        </div><!-- .featured-content-wrapper -->
                    </div><!-- .wrapper -->
                </article>
            <?php endforeach; ?>
        </div><!-- #featured-slider -->
    <?php endif ?>
     
    <?php }
    endif;