<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Web Artist Pro
 * @since Web Artist Pro 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Web Artist Pro 1.0.0
    */
    function web_artist_pro_add_testimonial_section() {
        $options = web_artist_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'web_artist_pro_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        web_artist_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Web Artist Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function web_artist_pro_get_testimonial_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();

        // Content type.
        $testimonial_content_type   = $options['testimonial_content_type'];
        $testimonial_count          = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 4;
        $content = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
        $query = new WP_Query( $args );
        $i = 1;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['subtitle']  = ! empty( $options['subtitle'] ) ? $options['subtitle'] : '';
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = get_the_content();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';
                $page_post['position']  = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'web_artist_pro_filter_testimonial_section_details', 'web_artist_pro_get_testimonial_section_details' );


if ( ! function_exists( 'web_artist_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Web Artist Pro 1.0.0
   *
   */
   function web_artist_pro_render_testimonial_section( $content_details = array() ) {
        $options = web_artist_pro_get_theme_options();
        $testimonial_bg_image       = ! empty( $options['testimonial_bg_image'] ) ? $options['testimonial_bg_image'] : get_template_directory_uri().'/assets/uploads/services-bg-03.png';

        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <?php if ( $options['home_layout'] == 'default-design' ): ?>
            <div id="client" class="relative">
                
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                </div><!-- .section-header -->

                <div class="section-content col-3" style="background-image:url('<?php echo esc_url($testimonial_bg_image); ?>')">
                    <div class="wrapper">
                        <div class="client-wrapper clear">

                        <?php $i=1; foreach ( $content_details as $content ) : ?>

                            <article class="hentry">
                                <div class="featured-image">
                                    <img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                </div><!-- .featured-image -->

                                <div class="entry-content">
                                    <p><?php echo wp_trim_words( wp_kses_post( $content['excerpt']), $options['testimonial_excerpt']  ); ?></p>
                                </div><!-- .entry-content -->
                                <div class="seperator"></div>
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    <p class="position"><?php echo esc_html( $content['position'] ); ?>
                                    </p>
                                </header>
                            </article>

                          <?php $i++; endforeach; ?>  

                        </div><!-- .client-wrapper -->

                        <?php if ( !empty( $options['testimonial_btn_link'] ) && !empty($options['testimonial_button'] ) && $options['home_layout'] == 'default-design' ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $options['testimonial_btn_link'] ); ?>" class="btn btn-fill" tabindex="0"><?php echo esc_html( $options['testimonial_button'] ); ?></a>
                        </div><!-- .read-more -->
                        <?php endif; ?>
                    </div><!-- .wrapper -->
                </div><!-- .section-content -->
            </div> 
        <?php endif; ?>

        <?php if ( $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'second-design'): ?>
            <div id="testimonial" class="relative page-section" style="background-image:url('<?php echo esc_url($testimonial_bg_image); ?>')">
                <div class="overlay"></div>
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows":false, "autoplay": true, "draggable": true, "fade": false }'>
                        <?php foreach ($content_details as $content): ?>
                            <article>
                                <div class="entry-container">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>">
                                    </div><!-- .featured-image -->

                                    <div class="entry-content">
                                        <p>“<?php echo wp_trim_words( wp_kses_post( $content['excerpt']), $options['testimonial_excerpt']  ); ?>”</p>
                                    </div><!-- .entry-content -->
                                    <div class="seperator"></div>
                                    <div class="header-wrapper">

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>">
                                                <?php echo esc_html($content['title']); ?>
                                            </a></h2>
                                            <p class="designation"><?php echo esc_html( $content['position'] ); ?></p>
                                        </header>
                                    </div><!-- .header-wrapper -->
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .client-slider -->
                </div><!-- .wrapper -->
            </div><!-- #testimonial -->
        <?php endif; ?>

        <?php if ( $options['home_layout'] == 'seventh-design') : ?>
            <div id="testimonial" class="relative page-section" style="background-image:url('<?php echo esc_url($testimonial_bg_image); ?>')">
                <div class="wrapper">
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['testimonial_subtitle'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows":false, "autoplay": true, "draggable": true, "fade": false }'>
                        <?php foreach ($content_details as $content): ?>
                            <article>
                                <div class="entry-container">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>">
                                    </div><!-- .featured-image -->

                                    <div class="entry-content">
                                        <p>“<?php echo wp_trim_words( wp_kses_post( $content['excerpt']), $options['testimonial_excerpt']  ); ?>”</p>
                                    </div><!-- .entry-content -->
                                    <div class="seperator"></div>
                                    <div class="header-wrapper">

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>">
                                                <?php echo esc_html($content['title']); ?>
                                            </a></h2>
                                            <p class="designation"><?php echo esc_html( $content['position'] ); ?></p>
                                        </header>
                                    </div><!-- .header-wrapper -->
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .client-slider -->
                </div><!-- .wrapper -->
            </div><!-- #testimonial -->
        <?php endif; ?>

             

    <?php }
endif;
            