<?php
/**
* Topic section
*
* This is the template for the content of topic section
*
* @package Theme Palace
* @subpackage Web Artist
* @since Web Artist 1.0.0
*/
if ( ! function_exists( 'web_artist_pro_add_topic_section' ) ) :
/**
* Add topic section
*
*@since Web Artist 1.0.0
*/
function web_artist_pro_add_topic_section() {
    $options = web_artist_pro_get_theme_options();
// Check if topic is enabled on frontpage
    $topic_enable = apply_filters( 'web_artist_pro_section_status', true, 'topic_section_enable' );

    if ( true !== $topic_enable ) {
        return false;
    }
// Get topic section details
    $section_details = array();
    $section_details = apply_filters( 'web_artist_pro_filter_topic_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render topic section now.
    web_artist_pro_render_topic_section( $section_details );
}
endif;

if ( ! function_exists( 'web_artist_pro_get_topic_section_details' ) ) :
/**
* topic section details.
*
* @since Web Artist 1.0.0
* @param array $input topic section details.
*/
function web_artist_pro_get_topic_section_details( $input ) {
    $options = web_artist_pro_get_theme_options();

// Content type.
    $topic_content_type  = $options['topic_content_type'];
    $topic_count = ! empty( $options['topic_count'] ) ? $options['topic_count'] : 4;

    $content = array();
    switch ( $topic_content_type ) {

        case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $topic_count; $i++ ) {
            if ( ! empty( $options['topic_content_page_' . $i] ) )
                $page_ids[] = $options['topic_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $topic_count ),
            'orderby'           => 'post__in',
            );                    
        break;

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $topic_count; $i++ ) {
            if ( ! empty( $options['topic_content_post_' . $i] ) )
                $post_ids[] = $options['topic_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $topic_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cat_id = ! empty( $options['topic_content_category'] ) ? $options['topic_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $topic_count ),
            'cat'               => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }


// Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['title']     = get_the_title();
    $page_post['url']       = get_the_permalink();

// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();


    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// topic section content details.
add_filter( 'web_artist_pro_filter_topic_section_details', 'web_artist_pro_get_topic_section_details' );


if ( ! function_exists( 'web_artist_pro_render_topic_section' ) ) :
/**
* Start topic section
*
* @return string topic content
* @since Web Artist 1.0.0
*
*/
function web_artist_pro_render_topic_section( $content_details = array() ) {
    $options = web_artist_pro_get_theme_options();
    $column = ! empty( $options['topic_column'] ) ? $options['topic_column'] : 'col-4';
    $i = 1;        

    if ( empty( $content_details ) ) {
        return;
    } ?>
    <div id="topics" class="page-section">
        <div class="wrapper">
            <div class="section-header-wrapper clear">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['topic_title'] ); ?></h2>
                </div>

                <?php if(!empty($options['topic_button'] ) && !empty($options['topic_button_url'])): ?>
                    <a href="<?php echo esc_url( $options['topic_button_url'] ); ?>" class="btn"><?php echo esc_html( $options['topic_button'] ); ?></a>
                <?php endif; ?>
            </div><!-- .section-header-wrapper -->

            <div class="section-content <?php echo esc_attr( $column ) ?> clear">
                <?php foreach ( $content_details as $content ) : ?>

                    <article class="hentry">
                        <div class="topic-wrapper">
                            <div class="topic-icon">
                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <i class="fa <?php echo ! empty( $options['topic_content_icon_' . $i] ) ? esc_attr( $options['topic_content_icon_' . $i] ) : 'fa-cogs'; ?>"></i>
                                </a>
                            </div><!-- .topic-icon -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                        </div><!-- .topic-wrapper -->
                    </article>

                    <?php $i++; endforeach; ?>

                </div>
                <?php if(!empty($options['topic_button'] ) && !empty($options['topic_button_url'])): ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['topic_button_url'] ); ?>" class="btn"><?php echo esc_html( $options['topic_button'] ); ?></a>
                    </div>
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #topics -->
        <?php }
        endif;
