<?php
/**
 * video section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */
if ( ! function_exists( 'web_artist_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since Web Artist 1.0.0
    */
    function web_artist_pro_add_video_section() {
        $options = web_artist_pro_get_theme_options();
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'web_artist_pro_section_status', true, 'video_section_enable' );

        if ( true !== $video_enable ) {
            return false;
        }
        // Get video section details
        $section_details = array();
        $section_details = apply_filters( 'web_artist_pro_filter_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render video section now.
        web_artist_pro_render_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'web_artist_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since Web Artist 1.0.0
    * @param array $input video section details.
    */
    function web_artist_pro_get_video_section_details( $input ) {
        $options = web_artist_pro_get_theme_options();

        // Content type.
        $video_content_type  = $options['video_content_type'];
        
        $content = array();
        switch ( $video_content_type ) {
            
            case 'custom':
                $custom['title']        = ! empty( $options['video_title'] ) ? $options['video_title'] : '';
                $custom['excerpt']      = ! empty( $options['video_description'] ) ? $options['video_description'] : '';
                $custom['image']        = ! empty( $options['video_image'] ) ? $options['video_image'] : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';
                $custom['url']          = ! empty( $options['video_btn_link'] ) ? $options['video_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['video_content_page'] ) ? $options['video_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['video_content_post'] ) ? $options['video_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $video_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['content']   = get_the_content( );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'web_artist_pro_filter_video_section_details', 'web_artist_pro_get_video_section_details' );


if ( ! function_exists( 'web_artist_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since Web Artist 1.0.0
   *
   */
   function web_artist_pro_render_video_section( $content_details = array() ) {
        $options = web_artist_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
            <div id="video" class="relative page-section" style="background-image:url('<?php echo esc_url( $content['image'] ) ; ?>')">
                <div class="wrapper">
                    <div class="video-wrapper">
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $content['title'] ) ; ?></h2>
                        </div>

                        <div class="section-content">
                            <?php if ( !empty( $options['video_url'] ) ): ?>
                                <div class="video-button">
                                    <a href="<?php echo esc_url( $options['video_url'] ); ?>" class="popup-youtube">
                                        <svg class="svg-inline--fa fa-play fa-w-14" viewBox="0 0 448 512"><path d="M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z"></path></svg>
                                    </a>
                                </div>
                            <?php endif ?>
                            
                            <div class="entry-content">
                                <p><?php echo wp_trim_words( wp_kses_post( $content['content']), $options['video_excerpt']  ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if ( !empty( $options['video_btn_title'] ) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="btn btn-fill"><?php echo esc_html( $options['video_btn_title'] ) ; ?></a>
                                </div><!-- .read-more -->
                            <?php endif ?>
                            
                        </div><!-- .section-content -->
                    </div>
                </div>
            </div>
        <?php endforeach; 
    }
endif;
