<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Web Artist
 * @since Web Artist 1.0.0
 */

$options = web_artist_pro_get_theme_options();


if ( ! function_exists( 'web_artist_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Web Artist 1.0.0
	 */
	function web_artist_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'web_artist_pro_doctype', 'web_artist_pro_doctype', 10 );


if ( ! function_exists( 'web_artist_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'web_artist_pro_before_wp_head', 'web_artist_pro_head', 10 );

if ( ! function_exists( 'web_artist_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'web-artist-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'web_artist_pro_page_start_action', 'web_artist_pro_page_start', 10 );



if ( ! function_exists( 'web_artist_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'web_artist_pro_page_end_action', 'web_artist_pro_page_end', 10 );

if ( ! function_exists( 'web_artist_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_header_start() { 
		$options = web_artist_pro_get_theme_options();
	?>
		<?php if ( $options['home_layout'] == 'fifth-design' && $options['topbar_section_enable'] == true ): ?>
			<div id="top-bar" class="relative">
	            <div class="wrapper">
	                <div class="col-2 clear">
	                    <div class="hentry">
	                        <ul class="contact-info clear">
	                        	<?php if ( !empty($options['topbar_contact']) ): ?>
	                            	<li>
		                            	<a href="tel:<?php echo esc_url( $options['topbar_contact'] ) ?>">
		                                <svg viewBox="0 0 480.56 480.56" class="icon-phone">
		                                    <path d="M365.354,317.9c-15.7-15.5-35.3-15.5-50.9,0c-11.9,11.8-23.8,23.6-35.5,35.6c-3.2,3.3-5.9,4-9.8,1.8
		                                    c-7.7-4.2-15.9-7.6-23.3-12.2c-34.5-21.7-63.4-49.6-89-81c-12.7-15.6-24-32.3-31.9-51.1c-1.6-3.8-1.3-6.3,1.8-9.4
		                                    c11.9-11.5,23.5-23.3,35.2-35.1c16.3-16.4,16.3-35.6-0.1-52.1c-9.3-9.4-18.6-18.6-27.9-28c-9.6-9.6-19.1-19.3-28.8-28.8
		                                    c-15.7-15.3-35.3-15.3-50.9,0.1c-12,11.8-23.5,23.9-35.7,35.5c-11.3,10.7-17,23.8-18.2,39.1c-1.9,24.9,4.2,48.4,12.8,71.3
		                                    c17.6,47.4,44.4,89.5,76.9,128.1c43.9,52.2,96.3,93.5,157.6,123.3c27.6,13.4,56.2,23.7,87.3,25.4c21.4,1.2,40-4.2,54.9-20.9
		                                    c10.2-11.4,21.7-21.8,32.5-32.7c16-16.2,16.1-35.8,0.2-51.8C403.554,355.9,384.454,336.9,365.354,317.9z"/>
		                                    <path d="M346.254,238.2l36.9-6.3c-5.8-33.9-21.8-64.6-46.1-89c-25.7-25.7-58.2-41.9-94-46.9l-5.2,37.1
		                                    c27.7,3.9,52.9,16.4,72.8,36.3C329.454,188.2,341.754,212,346.254,238.2z"/>
		                                    <path d="M403.954,77.8c-42.6-42.6-96.5-69.5-156-77.8l-5.2,37.1c51.4,7.2,98,30.5,134.8,67.2c34.9,34.9,57.8,79,66.1,127.5
		                                    l36.9-6.3C470.854,169.3,444.354,118.3,403.954,77.8z"/>
		                                </svg>
		                                <?php echo esc_html( $options['topbar_contact'] ) ?></a>
		                            </li>	
	                            <?php endif ?>
	                            <?php if ( !empty($options['topbar_email']) ): ?>
	                            	<li>
		                            	<a href="mailto:<?php echo esc_url( $options['topbar_email'] ) ?>">
		                                <svg viewBox="0 0 485.211 485.211" class="icon-phone">
		                                    <path d="M485.211,363.906c0,10.637-2.992,20.498-7.785,29.174L324.225,221.67l151.54-132.584
		                                    c5.895,9.355,9.446,20.344,9.446,32.219V363.906z M242.606,252.793l210.863-184.5c-8.653-4.737-18.397-7.642-28.908-7.642H60.651
		                                    c-10.524,0-20.271,2.905-28.889,7.642L242.606,252.793z M301.393,241.631l-48.809,42.734c-2.855,2.487-6.41,3.729-9.978,3.729
		                                    c-3.57,0-7.125-1.242-9.98-3.729l-48.82-42.736L28.667,415.23c9.299,5.834,20.197,9.329,31.983,9.329h363.911
		                                    c11.784,0,22.687-3.495,31.983-9.329L301.393,241.631z M9.448,89.085C3.554,98.44,0,109.429,0,121.305v242.602
		                                    c0,10.637,2.978,20.498,7.789,29.174l153.183-171.44L9.448,89.085z"/>
		                                </svg>
		                                <?php echo esc_html( $options['topbar_email'] ) ?></a>
		                            </li>	
	                            <?php endif ?>
	                        </ul><!-- .contact-info -->
	                    </div><!-- .hentry -->

	                    <?php if ( !empty( $options['topbar_btn_text'] ) ): ?>
	                        <div class="hentry">
		                        <div class="secondary-menu">
		                            <a href="<?php echo esc_url( $options['topbar_btn_url'] ) ?>" class="apply-now">
		                            	<?php echo esc_html( $options['topbar_btn_text'] ) ?>
		                            </a>
		                        </div><!-- .secondary-menu -->
		                    </div><!-- .hentry --> 		
	                   	<?php endif ?>	                    
	                </div><!-- .col-2 -->
	            </div><!-- .wrapper -->
	        </div><!-- #top-bar -->
		<?php endif ?>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'web_artist_pro_header_action', 'web_artist_pro_header_start', 10 );

if ( ! function_exists( 'web_artist_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_site_branding() {
		$options  = web_artist_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-menu">
			
			<div class="site-branding">
				<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
				<?php } 
				if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
					<div id="site-details">
						<?php
						if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
							if ( web_artist_pro_is_latest_posts() ) : ?>
								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php else : ?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
							endif;
						} 
						if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
							$description = get_bloginfo( 'description', 'display' );
							if ( $description || is_customize_preview() ) : ?>
								<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
							<?php
							endif; 
						}?>
					</div>
				<?php endif; ?>
			</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'web_artist_pro_header_action', 'web_artist_pro_site_branding', 20 );

if ( ! function_exists( 'web_artist_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_site_navigation() { ?>
		<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php _e('Primary Menu', 'web-artist-pro'); ?>">
		<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
            <span class="menu-label"><?php esc_html_e( 'Menu', 'web-artist-pro' ); ?></span>
                <?php
				echo web_artist_pro_get_svg( array( 'icon' => 'menu' ) );
				echo web_artist_pro_get_svg( array( 'icon' => 'close' ) );
				?>	
            </button><!-- .menu-toggle -->
			<?php 

			$social_menu = wp_nav_menu(array(
        			'theme_location' => 'social',
        			'container' => 'div',
    				'container_class' => 'social-icons',
        			'menu_class' => '',
        			'menu_id' => '',
        			'echo' => false,
        			'depth' => 1,
        			'link_before' => '<span class="screen-reader-text">',
					'link_after' => '</span>',
        		));

        		wp_nav_menu( array(
        			'theme_location' => 'primary',
        			'container' => 'div',
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'web_artist_pro_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s<li class="social-menu-item">' . $social_menu . '</li></ul>',
        		) );
        	?>
		</nav><!-- #site-navigation -->
		</div><!-- .site-menu -->

		<?php
	}
endif;
add_action( 'web_artist_pro_header_action', 'web_artist_pro_site_navigation', 30 );

 if ( ! function_exists( 'web_artist_pro_social_navigation' ) ) :
 	/**
 	 * Social navigation codes
 	 *
 	 * @since Web Artist 1.0.0
 	 *
 	 */
 	function web_artist_pro_social_navigation() {
		?>
		 <div id="social-navigation">
			<?php 

			$defaults = array(
         			'theme_location' => 'social',
         			'container' => 'div',
     				'container_class' => 'social-icons',
         			'menu_class' => '',
         			'menu_id' => '',
         			'echo' => true,
         			'fallback_cb' => 'web_artist_pro_menu_fallback_cb',
         			'depth' => 1,
         			'link_before' => '<span class="screen-reader-text">',
 					'link_after' => '</span>',
         		);
        		wp_nav_menu( $defaults );
         	?>
		</div><!-- #social-navigation
		<?php
	}
endif;
add_action( 'web_artist_pro_header_action', 'web_artist_pro_social_navigation', 40 );

if ( ! function_exists( 'web_artist_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_header_end() {
		?>
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'web_artist_pro_header_action', 'web_artist_pro_header_end', 50 );

if ( ! function_exists( 'web_artist_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'web_artist_pro_content_start_action', 'web_artist_pro_content_start', 10 );

if ( ! function_exists( 'web_artist_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_header_image() {
		if ( web_artist_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		if ( is_singular() ) :
			$header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php web_artist_pro_custom_header_banner_title(); ?></h2>
                </header>

                <?php web_artist_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->

	<?php
	}
endif;
add_action( 'web_artist_pro_header_image_action', 'web_artist_pro_header_image', 10 );

if ( ! function_exists( 'web_artist_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Web Artist 1.0.0
	 */
	function web_artist_pro_add_breadcrumb() {
		$options = web_artist_pro_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( web_artist_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * web_artist_pro_simple_breadcrumb hook
				 *
				 * @hooked web_artist_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'web_artist_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'web_artist_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'web_artist_pro_content_end_action', 'web_artist_pro_content_end', 10 );

if ( ! function_exists( 'web_artist_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_footer_start() {
		$options = web_artist_pro_get_theme_options();
		$footer_bg_image = ! empty( $options['footer_bg_image'] ) ? $options['footer_bg_image'] : '#';
		?>
		<footer id="colophon" class="site-footer" role="contentinfo" style="background-image:url('<?php echo esc_url( $footer_bg_image ); ?>')">
		<?php
	}
endif;
add_action( 'web_artist_pro_footer', 'web_artist_pro_footer_start', 10 );

if ( ! function_exists( 'web_artist_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_footer_site_info() {
		$options = web_artist_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_html( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info">
			<div class="wrapper">
                <span>
                	<?php 
                	echo web_artist_pro_santize_allow_tag( $copyright_text ); 
                	if ( function_exists( 'the_privacy_policy_link' ) ) {
						the_privacy_policy_link( ' | ' );
					}
                	?>
            	</span>

            	<?php
            	
            	?>
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'web_artist_pro_footer', 'web_artist_pro_footer_site_info', 40 );

if ( ! function_exists( 'web_artist_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_footer_scroll_to_top() {
		$options  = web_artist_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo web_artist_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'web_artist_pro_footer', 'web_artist_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'web_artist_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'web_artist_pro_footer', 'web_artist_pro_footer_end', 100 );

if ( ! function_exists( 'web_artist_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_loader() {
		$options = web_artist_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo web_artist_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'web_artist_pro_before_header', 'web_artist_pro_loader', 10 );

if ( ! function_exists( 'web_artist_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Web Artist 1.0.0
	 *
	 */
	function web_artist_pro_infinite_loader_spinner() { 
		global $post;
		$options = web_artist_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . web_artist_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'web_artist_pro_infinite_loader_spinner_action', 'web_artist_pro_infinite_loader_spinner', 10 );
